#
# spec file for package tomcat
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2000-2009, JPackage Project
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define jspspec 2.3
%define servletspec 4.0
%define elspec 3.0
%define major_version 9
%define minor_version 0
%define micro_version 106
%define packdname apache-tomcat-%{version}-src
# FHS 2.3 compliant tree structure - http://www.pathname.com/fhs/2.3/
%global basedir /srv/%{name}
%define appdir %{basedir}/webapps
%define bindir %{_datadir}/%{name}/bin
%define confdir %{_sysconfdir}/%{name}
%define homedir %{_datadir}/%{name}
%define libdir %{_javadir}/%{name}
%define logdir %{_localstatedir}/log/%{name}
%define cachedir %{_localstatedir}/cache/%{name}
%define tempdir %{cachedir}/temp
%define workdir %{cachedir}/work
%define tomcatappdir %{_datadir}/%{name}/tomcat-webapps
%define javac_target 1.8
#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir %{_localstatedir}/adm/fillup-templates
%endif
Name:           tomcat
Version:        %{major_version}.%{minor_version}.%{micro_version}
Release:        1.1
Summary:        Apache Servlet/JSP/EL Engine, RI for Servlet 4.0/JSP 2.3/EL 3.0 API
License:        Apache-2.0
Group:          Productivity/Networking/Web/Servers
URL:            https://tomcat.apache.org
Source0:        https://archive.apache.org/dist/tomcat/tomcat-%{major_version}/v%{version}/src/%{packdname}.tar.gz
Source1:        %{name}-%{major_version}.%{minor_version}.conf
Source3:        %{name}-%{major_version}.%{minor_version}.sysconfig
Source4:        %{name}-%{major_version}.%{minor_version}.wrapper
Source5:        %{name}-%{major_version}.%{minor_version}.logrotate
Source6:        %{name}-%{major_version}.%{minor_version}-digest.script
Source7:        %{name}-%{major_version}.%{minor_version}-tool-wrapper.script
Source11:       %{name}-%{major_version}.%{minor_version}.service
Source20:       %{name}-%{major_version}.%{minor_version}-jsvc.service
Source21:       tomcat-functions
Source30:       tomcat-preamble
Source31:       tomcat-server
Source32:       tomcat-named.service
Source100:      valve.xslt
Source101:      allowLinking.xslt
Source1000:     tomcat-rpmlintrc
Source1001:     https://archive.apache.org/dist/tomcat/tomcat-%{major_version}/v%{version}/src/%{packdname}.tar.gz.asc
Source1002:     https://downloads.apache.org/tomcat/tomcat-9/KEYS#/%{name}.keyring
#PATCH-FIX-UPSTREAM: from jpackage.org package
Patch0:         %{name}-%{major_version}.%{minor_version}-bootstrap-MANIFEST.MF.patch
#PATCH-FIX-UPSTREAM: from jpackage.org package
Patch1:         %{name}-%{major_version}.%{minor_version}-tomcat-users-webapp.patch
# PATCH-FIX-SLE: Change security manager default policies bnc#891264
Patch2:         %{name}-%{major_version}.%{minor_version}-sle.catalina.policy.patch
# PATCH-FIX-OPENSUSE: build javadoc with the same java source level as the class files
Patch3:         %{name}-%{major_version}.%{minor_version}-javadoc.patch
# PATCH-FIX-OPENSUSE: include all necessary aqute-bnd jars
Patch4:         tomcat-9.0-osgi-build.patch
# PATCH-FIX-OPENSUSE: build against our ecj that does not have CompilerOptions.VERSION_16
Patch5:         %{name}-%{major_version}.%{minor_version}-jdt.patch
# PATCH-FIX-OPENSUSE: set ajp connector secreteRequired to false by default to avoid tomcat not starting
Patch6:         tomcat-9.0.75-secretRequired-default.patch
Patch7:         tomcat-9.0-fix_catalina.patch
Patch8:         tomcat-9.0-logrotate_everything.patch
Patch9:         tomcat-9.0-build-with-java-11.patch
BuildRequires:  ant >= 1.8.1
BuildRequires:  ant-antlr
BuildRequires:  apache-commons-collections
BuildRequires:  apache-commons-daemon
BuildRequires:  apache-commons-dbcp >= 2.0
BuildRequires:  apache-commons-pool2
BuildRequires:  aqute-bnd >= 5.2
BuildRequires:  aqute-bndlib >= 5.2
BuildRequires:  ecj >= 4.4.0
BuildRequires:  fdupes
BuildRequires:  findutils
BuildRequires:  geronimo-jaf-1_0_2-api
BuildRequires:  geronimo-jaxrpc-1_1-api
BuildRequires:  geronimo-qname-1_1-api
BuildRequires:  geronimo-saaj-1_1-api
BuildRequires:  jakarta-taglibs-standard >= 1.1
BuildRequires:  java-devel >= 1.8
BuildRequires:  javapackages-local
BuildRequires:  junit
BuildRequires:  pkgconfig
BuildRequires:  sed
BuildRequires:  systemd-rpm-macros
BuildRequires:  unzip
BuildRequires:  wsdl4j
BuildRequires:  zip
BuildRequires:  pkgconfig(systemd)
Requires:       %{name}-lib = %{version}-%{release}
Requires:       apache-commons-daemon
Requires:       apache-commons-dbcp
Requires:       apache-commons-logging
Requires:       apache-commons-pool2
Requires:       java >= 1.8
Requires(post): %fillup_prereq
Requires(post): libxslt-tools
# for runuser
Requires(post): util-linux
Requires(pre):  shadow
Recommends:     libtcnative-1-0 >= 1.1.24
Recommends:     logrotate
Conflicts:      %{name}-implementation
Provides:       %{name}-implementation = %{version}
Provides:       group(tomcat)
Provides:       user(tomcat)
BuildArch:      noarch
%systemd_ordering

%description
Tomcat is the servlet container that is used in the official Reference
Implementation for the Java Servlet and JavaServer Pages technologies.
The Java Servlet and JavaServer Pages specifications are developed by
Sun under the Java Community Process.

ATTENTION: This tomcat is built with java 1.8.0.

%package admin-webapps
Summary:        The host manager and manager web applications for Apache Tomcat
Group:          Productivity/Networking/Web/Servers
Requires:       %{name} = %{version}-%{release}
Requires(post): libxslt-tools
# for runuser
Requires(post): util-linux
Conflicts:      %{name}-implementation-admin-webapps
Provides:       %{name}-implementation-admin-webapps = %{version}

%description admin-webapps
The host manager and manager web-based applications for Apache Tomcat.

%package embed
Summary:        Libraries for Embedding Apache Tomcat
Group:          Productivity/Networking/Web/Servers
Conflicts:      %{name}-implementation-embed
Provides:       %{name}-implementation-embed = %{version}

%description embed
Embeddeding support (various libraries) for Apache Tomcat.

%package docs-webapp
Summary:        The "docs" web application for Apache Tomcat
Group:          Productivity/Networking/Web/Servers
Requires:       %{name} = %{version}-%{release}
Requires(post): libxslt-tools
# for runuser
Requires(post): util-linux
Conflicts:      %{name}-implementation-docs-webapp
Provides:       %{name}-implementation-docs-webapp = %{version}

%description docs-webapp
The documentation of web application for Apache Tomcat.

%package el-3_0-api
Summary:        Expression Language v3.0 API
Group:          Development/Libraries/Java
Requires(post): update-alternatives
Requires(preun): update-alternatives
Conflicts:      %{name}-implementation-el-api
Provides:       %{name}-el-%{elspec}-api = %{version}-%{release}
Provides:       el_3_0_api = %{version}-%{release}
Provides:       el_api = %{elspec}
Obsoletes:      el_api < %{elspec}
Obsoletes:      tomcat-el-2_2-api
Provides:       %{name}-implementation-el-api = %{version}

%description el-3_0-api
Expression Language API version 3.0.

%package javadoc
Summary:        Javadoc generated documentation for Apache Tomcat
Group:          Documentation/HTML
Conflicts:      %{name}-implementation-javadoc
Provides:       %{name}-implementation-javadoc = %{version}
BuildArch:      noarch

%description javadoc
Javadoc generated documentation files for Apache Tomcat.

%package jsp-2_3-api
Summary:        Apache Tomcat JSP API implementation classes
Group:          Productivity/Networking/Web/Servers
Requires:       mvn(org.apache.tomcat:tomcat-el-api)
Requires:       mvn(org.apache.tomcat:tomcat-servlet-api)
Requires(post): update-alternatives
Requires(postun): update-alternatives
Conflicts:      %{name}-implementation-jsp-api
Provides:       %{name}-implementation-jsp-api = %{version}
Provides:       %{name}-jsp-%{jspspec}-api
Provides:       jsp = %{jspspec}
Provides:       jsp23
Obsoletes:      jsp < %{jspspec}
Obsoletes:      tomcat-jsp-2_2-api

%description jsp-2_3-api
Apache Tomcat JSP API implementation classes version 2.3

%package jsvc
Summary:        Apache jsvc wrapper for Apache Tomcat as separate service
Group:          Productivity/Networking/Web/Servers
Requires:       %{name} = %{version}-%{release}
Requires:       apache-commons-daemon-jsvc
Conflicts:      %{name}-implementation-jsvc
Provides:       %{name}-implementation-jsvc = %{version}
%systemd_ordering

%description jsvc
Systemd service and wrapper scripts to start tomcat with jsvc,
which allows tomcat to perform some privileged operations
(e.g. bind to a port < 1024) and then switch identity to a non-privileged user.

%package lib
Summary:        Libraries needed to run the Tomcat Web container
Group:          Productivity/Networking/Web/Servers
Requires:       %{name}-el-%{elspec}-api = %{version}-%{release}
Requires:       %{name}-jsp-%{jspspec}-api = %{version}-%{release}
Requires:       %{name}-servlet-%{servletspec}-api = %{version}-%{release}
Requires(post): ecj >= 4.4
Requires(preun): coreutils
Conflicts:      %{name}-implementation-lib
Provides:       jakarta-commons-dbcp-tomcat5 = 1.4
Obsoletes:      jakarta-commons-dbcp-tomcat5 < 1.4
Provides:       %{name}-implementation-lib = %{version}

%description lib
Libraries required to successfully run the Tomcat Web container

%package servlet-4_0-api
Summary:        Apache Tomcat Servlet API implementation classes
Group:          Productivity/Networking/Web/Servers
Requires(post): update-alternatives
Requires(postun): update-alternatives
Conflicts:      %{name}-implementation-servlet-api
Provides:       %{name}-servlet-%{servletspec}-api = %{version}-%{release}
Provides:       servlet = %{servletspec}
Provides:       servlet31
Provides:       servlet7
Obsoletes:      servlet < %{servletspec}
Obsoletes:      tomcat-servlet-3_0-api
Obsoletes:      tomcat-servlet-3_1-api
Provides:       %{name}-implementation-servlet-api = %{version}

%description servlet-4_0-api
Apache Tomcat Servlet API implementation classes version 3.1

%package webapps
Summary:        ROOT and examples web applications for Apache Tomcat
Group:          Productivity/Networking/Web/Servers
Requires:       %{name} = %{version}-%{release}
Requires:       jakarta-taglibs-standard >= 1.1
Requires(post): libxslt-tools
# for runuser
Requires(post): util-linux
Conflicts:      %{name}-implementation-webapps
Provides:       %{name}-implementation-webapps = %{version}

%description webapps
The ROOT and examples web applications for Apache Tomcat

%prep
%autosetup -p1 -n %{packdname}

# remove pre-built binaries and windows files
find . -type f \( -name "*.bat" -o -name "*.class" -o -name Thumbs.db -o -name "*.gz" -o \
          -name "*.jar" -o -name "*.war" -o -name "*.zip" \) -print -delete

# remove date from docs
sed -i -e '/build-date/ d' webapps/docs/tomcat-docs.xsl

%build

ln -s $(build-classpath jakarta-taglibs-core) webapps/examples/WEB-INF/lib/jstl.jar
ln -s $(build-classpath jakarta-taglibs-standard) webapps/examples/WEB-INF/lib/standard.jar

export CLASSPATH=
export OPT_JAR_LIST="xalan-j2-serializer"
export ANT_OPTS=-Xmx500M

# we don't care about the tarballs and we're going to replace
# so just create a dummy file for later removal
touch HACK
mkdir -p HACKDIR
touch HACKDIR/build.xml

ant -Dbase.path="." \
    -Dadd.osgi.jar.metadata="true" \
    -Djava.7.home="%{java_home}" \
    -Dbuild.compiler="modern" \
    -Dcommons-collections.jar="$(build-classpath commons-collections)" \
    -Dcommons-daemon.jar="$(build-classpath commons-daemon)" \
    -Dcommons-daemon.native.src.tgz="HACK" \
    -Djasper-jdt.jar="$(build-classpath ecj/ecj)" \
    -Djdt.jar="$(build-classpath ecj/ecj)" \
    -Dtomcat-native.tar.gz="HACK" \
    -Dtomcat-native.home="." \
    -Dcommons-daemon.native.win.mgr.exe="HACK" \
    -Dnsis.exe="HACK" \
    -Djaxrpc-lib.jar="$(build-classpath geronimo-jaxrpc-1.1-api)" \
    -Dwsdl4j-lib.jar="$(build-classpath wsdl4j)" \
    -Dsaaj-api.jar="$(build-classpath geronimo-saaj-1.1-api)" \
    -Dbnd.jar="$(build-classpath aqute-bnd/biz.aQute.bnd)" \
    -Dbnd.dir="%{_javadir}/aqute-bnd" \
    -Dosgiannotation.jar="$(build-classpath osgi-annotation/osgi.annotation)" \
    -Dosgi-annotations.jar="$(build-classpath aqute-bnd/biz.aQute.bnd.annotation)" \
    -Dosgicmpn.jar="$(build-classpath osgi-compendium/osgi.cmpn)" \
	-Dslf4j-api.jar="$(build-classpath slf4j/slf4j-api)" \
    -Dcommons-pool.home="$(build-classpath commons-pool2)" \
    -Dcommons-dbcp.home="$(build-classpath commons-dbcp2)" \
    -Dno.build.dbcp=true \
    -Dversion="%{version}" \
    -Dversion.build="%{micro_version}" \
    deploy javadoc package embed-jars

# remove some jars that we'll replace with symlinks later
rm output/build/bin/commons-daemon.jar \
        output/build/lib/ecj.jar

pushd output/dist/src/webapps/docs/appdev/sample/src
mkdir -p ../web/WEB-INF/classes
javac -source %{javac_target} -target %{javac_target} -cp ../../../../../../../../output/build/lib/servlet-api.jar -d ../web/WEB-INF/classes mypackage/Hello.java
pushd ../web
jar cf ../../../../../../../../output/build/webapps/docs/appdev/sample/sample.war *
popd
popd

%install
# build initial path structure
install -d -m 0755 %{buildroot}%{_bindir}
install -d -m 0755 %{buildroot}%{_sbindir}
install -d -m 0755 %{buildroot}%{_javadocdir}/%{name}
install -d -m 0755 %{buildroot}%{_initddir}
install -d -m 0755 %{buildroot}%{_sysconfdir}/logrotate.d
install -d -m 0755 %{buildroot}%{_sysconfdir}/sysconfig
install -d -m 0755 %{buildroot}%{appdir}
install -d -m 0755 %{buildroot}%{tomcatappdir}
install -d -m 0755 %{buildroot}%{bindir}
install -d -m 0775 %{buildroot}%{confdir}
install -d -m 0755 %{buildroot}%{cachedir}/Catalina/localhost
install -d -m 0755 %{buildroot}%{confdir}/conf.d
/bin/echo "Place your custom *.conf files here. Shell expansion is supported." > %{buildroot}%{confdir}/conf.d/README
install -d -m 0755 %{buildroot}%{libdir}
install -d -m 0775 %{buildroot}%{logdir}
/bin/touch %{buildroot}%{logdir}/catalina.out
install -d -m 0775 %{buildroot}%{_localstatedir}/lib/tomcats
/bin/echo "%{name}-%{major_version}.%{minor_version}.%{micro_version} RPM installed" >> %{buildroot}%{logdir}/catalina.out
install -d -m 0775 %{buildroot}%{homedir}
install -d -m 0775 %{buildroot}%{tempdir}
install -d -m 0775 %{buildroot}%{workdir}
install -d -m 0755 %{buildroot}%{_unitdir}
install -d -m 0755 %{buildroot}%{_libexecdir}/%{name}
install -d -m 0755 %{buildroot}%{_fillupdir}

cp -a %{SOURCE100} %{buildroot}%{confdir}
cp -a %{SOURCE101} %{buildroot}%{confdir}

# move things into place
# First copy supporting libs to tomcat lib
pushd output/build
    cp -a bin/*.{jar,xml} %{buildroot}%{bindir}
    cp -a conf/*.{policy,properties,xml} %{buildroot}%{confdir}
    cp -a lib/*.jar %{buildroot}%{libdir}
    cp -a webapps/* %{buildroot}%{tomcatappdir}
popd
# tomcat embedded
pushd output/embed
    cp -a *.jar %{buildroot}%{libdir}
popd

# javadoc
cp -a output/dist/webapps/docs/api/* %{buildroot}%{_javadocdir}/%{name}

sed -e "s|\@\@\@TCHOME\@\@\@|%{homedir}|g" \
   -e "s|\@\@\@TCTEMP\@\@\@|%{tempdir}|g" \
   -e "s|\@\@\@LIBDIR\@\@\@|%{_libdir}|g" %{SOURCE1} \
    > %{buildroot}%{confdir}/%{name}.conf
sed -e "s|\@\@\@TCHOME\@\@\@|%{homedir}|g" \
   -e "s|\@\@\@TCTEMP\@\@\@|%{tempdir}|g" \
   -e "s|\@\@\@LIBDIR\@\@\@|%{_libdir}|g" %{SOURCE3} \
    > %{buildroot}%{_fillupdir}/sysconfig.%{name}
sed -e "s|@LIBEXECDIR@|%{_libexecdir}|g" %{SOURCE4} \
    > %{buildroot}%{_sbindir}/%{name}
sed -e "s|@LIBEXECDIR@|%{_libexecdir}|g" %{SOURCE11} \
    > %{buildroot}%{_unitdir}/%{name}.service
sed -e "s|@LIBEXECDIR@|%{_libexecdir}|g" %{SOURCE20} \
    > %{buildroot}%{_unitdir}/%{name}-jsvc.service
sed -e "s|\@\@\@TCLOG\@\@\@|%{logdir}|g" %{SOURCE5} \
    > %{buildroot}%{_sysconfdir}/logrotate.d/%{name}
sed -e "s|\@\@\@TCHOME\@\@\@|%{homedir}|g" \
   -e "s|\@\@\@TCTEMP\@\@\@|%{tempdir}|g" \
   -e "s|\@\@\@LIBDIR\@\@\@|%{_libdir}|g" %{SOURCE6} \
    > %{buildroot}%{_bindir}/%{name}-digest
sed -e "s|\@\@\@TCHOME\@\@\@|%{homedir}|g" \
   -e "s|\@\@\@TCTEMP\@\@\@|%{tempdir}|g" \
   -e "s|\@\@\@LIBDIR\@\@\@|%{_libdir}|g" %{SOURCE7} \
    > %{buildroot}%{_bindir}/%{name}-tool-wrapper

sed -e "s|@LIBEXECDIR@|%{_libexecdir}|g" %{SOURCE21} \
    > %{buildroot}%{_libexecdir}/%{name}/functions
sed -e "s|@LIBEXECDIR@|%{_libexecdir}|g" %{SOURCE30} \
    > %{buildroot}%{_libexecdir}/%{name}/preamble
chmod 0755 %{buildroot}%{_libexecdir}/%{name}/preamble
sed -e "s|@LIBEXECDIR@|%{_libexecdir}|g" %{SOURCE31} \
    > %{buildroot}%{_libexecdir}/%{name}/server
chmod 0755 %{buildroot}%{_libexecdir}/%{name}/server
sed -e "s|@LIBEXECDIR@|%{_libexecdir}|g" %{SOURCE32} \
    > %{buildroot}%{_unitdir}/%{name}@.service

ln -sf %{_sbindir}/service %{buildroot}/%{_sbindir}/rc%{name}
ln -sf %{_sbindir}/service %{buildroot}/%{_sbindir}/rc%{name}-jsvc

# create jsp and servlet and el API symlinks
pushd %{buildroot}%{_javadir}
   mv %{name}/jsp-api.jar %{name}-jsp-%{jspspec}-api.jar
   ln -s %{name}-jsp-%{jspspec}-api.jar %{name}-jsp-api.jar
   mv %{name}/servlet-api.jar %{name}-servlet-%{servletspec}-api.jar
   ln -s %{name}-servlet-%{servletspec}-api.jar %{name}-servlet-api.jar
   ln -s %{name}-servlet-%{servletspec}-api.jar %{name}-servlet.jar
   mv %{name}/el-api.jar %{name}-el-%{elspec}-api.jar
   ln -s %{name}-el-%{elspec}-api.jar %{name}-el-api.jar
popd

pushd output/build
    %{_bindir}/build-jar-repository -s lib commons-collections \
                                        commons-dbcp2 commons-pool2 ecj/ecj 2>&1
    # need to use -p here with b-j-r otherwise the examples webapp fails to
    # load with a java.io.IOException
    %{_bindir}/build-jar-repository -p webapps/examples/WEB-INF/lib \
    taglibs-core.jar taglibs-standard.jar 2>&1
popd

pushd %{buildroot}%{libdir}
    # symlink JSP and servlet and el API jars
    ln -s ../%{name}-jsp-%{jspspec}-api.jar .
    ln -s ../%{name}-servlet-%{servletspec}-api.jar .
    ln -s ../%{name}-el-%{elspec}-api.jar .
    ln -s $(build-classpath commons-collections) commons-collections.jar
    rm -f commons-dbcp.jar
    ln -s $(build-classpath commons-dbcp2) commons-dbcp2.jar
    ln -s $(build-classpath commons-pool2) commons-pool2.jar
    ln -s $(build-classpath ecj/ecj) jasper-jdt.jar
    rm ecj.jar
    ln -s $(build-classpath ecj/ecj) ecj.jar

    # Temporary copy the juli jar here from %%{_datadir}/java/tomcat (for maven depmap)
    cp -a %{buildroot}%{bindir}/tomcat-juli.jar ./
popd

# symlink to the FHS locations where we've installed things
pushd %{buildroot}%{homedir}
    ln -s %{appdir} webapps
    ln -s %{confdir} conf
    ln -s %{libdir} lib
    ln -s %{logdir} logs
    ln -s %{tempdir} temp
    ln -s %{workdir} work
popd

# install sample webapp
mkdir -p %{buildroot}%{tomcatappdir}/sample
pushd %{buildroot}%{tomcatappdir}/sample
jar xf %{buildroot}%{tomcatappdir}/docs/appdev/sample/sample.war
popd

pushd %{buildroot}%{tomcatappdir}/examples/WEB-INF/lib
ln -s -f $(build-classpath jakarta-taglibs-core) jstl.jar
ln -s -f $(build-classpath jakarta-taglibs-standard) standard.jar
popd

rm %{buildroot}%{tomcatappdir}/docs/appdev/sample/sample.war

# Install the maven metadata
install -d -m 0755 %{buildroot}%{_mavenpomdir}
pushd output/dist/src/res/maven
for pom in *.pom; do
    # fix-up version in all pom files
    sed -i 's/@MAVEN.DEPLOY.VERSION@/%{version}/g' $pom
done

# we won't install dbcp, juli-adapters and juli-extras pom files
for libname in annotations-api catalina jasper-el jasper catalina-ha jaspic-api; do
    cp -a %{name}-$libname.pom %{buildroot}%{_mavenpomdir}/JPP.%{name}-$libname.pom
    %add_maven_depmap JPP.%{name}-$libname.pom %{name}/$libname.jar
done

# servlet-api jsp-api and el-api are not in tomcat subdir, since they are widely re-used elsewhere
cp -a tomcat-jsp-api.pom %{buildroot}%{_mavenpomdir}/JPP-tomcat-jsp-api.pom
%add_maven_depmap JPP-tomcat-jsp-api.pom tomcat-jsp-api.jar -f jsp-api -a "org.eclipse.jetty.orbit:javax.servlet.jsp"

cp -a tomcat-el-api.pom %{buildroot}%{_mavenpomdir}/JPP-tomcat-el-api.pom
%add_maven_depmap JPP-tomcat-el-api.pom tomcat-el-api.jar -f el-api -a "org.eclipse.jetty.orbit:javax.el"

cp -a tomcat-servlet-api.pom %{buildroot}%{_mavenpomdir}/JPP-tomcat-servlet-api.pom
# Generate a depmap fragment javax.servlet:servlet-api pointing to
# tomcat-servlet-3.0-api for backwards compatibility
# also provide jetty depmap (originally in jetty package, but it's cleaner to have it here
%add_maven_depmap JPP-tomcat-servlet-api.pom tomcat-servlet-api.jar -f servlet-api -a "org.mortbay.jetty:servlet-api"

# two special pom where jar files have different names
cp -a tomcat-tribes.pom %{buildroot}%{_mavenpomdir}/JPP.%{name}-catalina-tribes.pom
%add_maven_depmap JPP.%{name}-catalina-tribes.pom %{name}/catalina-tribes.jar

cp -a tomcat-coyote.pom %{buildroot}%{_mavenpomdir}/JPP.%{name}-tomcat-coyote.pom
%add_maven_depmap JPP.%{name}-tomcat-coyote.pom %{name}/tomcat-coyote.jar

cp -a tomcat-jni.pom %{buildroot}%{_mavenpomdir}/JPP.%{name}-tomcat-jni.pom
%add_maven_depmap JPP.%{name}-tomcat-jni.pom %{name}/tomcat-jni.jar

cp -a tomcat-juli.pom %{buildroot}%{_mavenpomdir}/JPP.%{name}-tomcat-juli.pom
%add_maven_depmap JPP.%{name}-tomcat-juli.pom %{name}/tomcat-juli.jar

cp -a tomcat-jdbc.pom %{buildroot}%{_mavenpomdir}/JPP.%{name}-tomcat-jdbc.pom
%add_maven_depmap JPP.%{name}-tomcat-jdbc.pom %{name}/tomcat-jdbc.jar

cp -a tomcat-dbcp.pom %{buildroot}%{_mavenpomdir}/JPP.%{name}-tomcat-dbcp.pom
%add_maven_depmap JPP.%{name}-tomcat-dbcp.pom %{name}/tomcat-dbcp.jar

cp -a tomcat-api.pom %{buildroot}%{_mavenpomdir}/JPP.%{name}-tomcat-api.pom
%add_maven_depmap JPP.%{name}-tomcat-api.pom %{name}/tomcat-api.jar

cp -a tomcat-util.pom %{buildroot}%{_mavenpomdir}/JPP.%{name}-tomcat-util.pom
%add_maven_depmap JPP.%{name}-tomcat-util.pom %{name}/tomcat-util.jar

cp -a tomcat-util-scan.pom %{buildroot}%{_mavenpomdir}/JPP.%{name}-tomcat-util-scan.pom
%add_maven_depmap JPP.%{name}-tomcat-util-scan.pom %{name}/tomcat-util-scan.jar

cp -a tomcat-websocket-api.pom %{buildroot}%{_mavenpomdir}/JPP.%{name}-websocket-api.pom
%add_maven_depmap JPP.%{name}-websocket-api.pom %{name}/websocket-api.jar

cp -a tomcat-websocket.pom %{buildroot}%{_mavenpomdir}/JPP.%{name}-tomcat-websocket.pom
%add_maven_depmap JPP.%{name}-tomcat-websocket.pom %{name}/tomcat-websocket.jar

cp -a tomcat-embed-core.pom %{buildroot}%{_mavenpomdir}/JPP.%{name}-tomcat-embed-core.pom
%add_maven_depmap JPP.%{name}-tomcat-embed-core.pom %{name}/tomcat-embed-core.jar -f embed

cp -a tomcat-embed-el.pom %{buildroot}%{_mavenpomdir}/JPP.%{name}-tomcat-embed-el.pom
%add_maven_depmap JPP.%{name}-tomcat-embed-el.pom %{name}/tomcat-embed-el.jar -f embed

cp -a tomcat-embed-jasper.pom %{buildroot}%{_mavenpomdir}/JPP.%{name}-tomcat-embed-jasper.pom
%add_maven_depmap JPP.%{name}-tomcat-embed-jasper.pom %{name}/tomcat-embed-jasper.jar -f embed

cp -a tomcat-embed-websocket.pom %{buildroot}%{_mavenpomdir}/JPP.%{name}-tomcat-embed-websocket.pom
%add_maven_depmap JPP.%{name}-tomcat-embed-websocket.pom %{name}/tomcat-embed-websocket.jar -f embed

# replace temporary copy with link
ln -s -f %{bindir}/tomcat-juli.jar %{buildroot}%{libdir}/

# bnc#424675
ln -s %{cachedir}/Catalina %{buildroot}/%{confdir}
rm -rf %{buildroot}/%{confdir}/Catalina
ln -s %{cachedir}/Catalina %{buildroot}/%{confdir}/

# bnc#418664
install -d -m 0755 %{buildroot}/%{_sysconfdir}/ant.d/
echo "%{name}/catalina-ant" > %{buildroot}/%{_sysconfdir}/ant.d/catalina-ant
%fdupes %{buildroot} /srv/%{name}
#bnc#565901
ln -sf %{_sbindir}/%{name} %{buildroot}/%{bindir}/catalina.sh

# Install update-alternatives content
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
ln -s -f %{_sysconfdir}/alternatives/el_api %{buildroot}%{_javadir}/%{name}-el_api.jar
ln -s -f %{_sysconfdir}/alternatives/el_1_0_api %{buildroot}%{_javadir}/%{name}-el_1_0_api.jar
ln -s -f %{_sysconfdir}/alternatives/jsp %{buildroot}%{_javadir}/%{name}-jsp.jar
# To avoid conflicts with servletapi4 and servletapi5 create a link to incorrect /etc/alternatives/servlet.jar.
# It will be changed anyways to the correct symlink by update-alternatives.
ln -s -f %{_sysconfdir}/alternatives/servlet.jar %{buildroot}%{_javadir}/servlet.jar

%pre
# add the tomcat user and group
getent group tomcat >/dev/null || %{_sbindir}/groupadd -r tomcat
getent passwd tomcat >/dev/null || %{_sbindir}/useradd -c "Apache Tomcat" \
	-g tomcat -s /sbin/nologin -r -d %{homedir} tomcat
%service_add_pre %{name}.service

%post
%service_add_post %{name}.service
%{fillup_only %{name}}
chown -R tomcat:tomcat %{confdir}/server.xml
runuser -u tomcat -g tomcat -- xsltproc --output %{confdir}/server.xml %{confdir}/valve.xslt %{confdir}/server.xml

%preun
%service_del_preun %{name}.service

%postun
%service_del_postun %{name}.service

%pre jsvc
%service_add_pre %{name}-jsvc.service

%post jsvc
%service_add_post %{name}-jsvc.service

%preun jsvc
%service_del_preun %{name}-jsvc.service

%postun jsvc
%service_del_postun %{name}-jsvc.service

%post el-3_0-api
update-alternatives --install %{_javadir}/%{name}-el_api.jar el_api %{_javadir}/%{name}-el-%{elspec}-api.jar 20300
update-alternatives --install %{_javadir}/%{name}-el_1_0_api.jar el_1_0_api %{_javadir}/%{name}-el-%{elspec}-api.jar 20300

%preun el-3_0-api
if [ $1 -eq 0 ] ; then
    update-alternatives --remove el_api %{_javadir}/%{name}-el-%{elspec}-api.jar
    update-alternatives --remove el_1_0_api %{_javadir}/%{name}-el-%{elspec}-api.jar
fi

%post jsp-2_3-api
update-alternatives --install %{_javadir}/%{name}-jsp.jar jsp \
    %{_javadir}/%{name}-jsp-%{jspspec}-api.jar 20200

%postun jsp-2_3-api
if [ $1 -eq 0 ] ; then
    update-alternatives --remove jsp \
        %{_javadir}/%{name}-jsp-%{jspspec}-api.jar
fi

%post servlet-4_0-api
update-alternatives --install %{_javadir}/servlet.jar servlet \
    %{_javadir}/%{name}-servlet-%{servletspec}-api.jar 30000
# Fix for bsc#1092163.
# Keep the /usr/share/java/tomcat-servlet.jar symlink for compatibility.
# In case of update from an older version where /usr/share/java/tomcat-servlet.jar is an alternatives symlink
# the update-alternatives in the new version will cause a rename tomcat-servlet.jar -> servlet.jar.
# This makes sure the tomcat-servlet.jar is recreated if it's missing because of the rename.
if [ ! -f %{_javadir}/%{name}-servlet.jar ]; then
    echo "Recreating symlink %{_javadir}/%{name}-servlet.jar"
    ln -s %{_javadir}/%{name}-servlet-%{servletspec}-api.jar %{_javadir}/%{name}-servlet.jar
fi

%postun servlet-4_0-api
if [ $1 -eq 0 ] ; then
    if [ ! -f %{_sysconfdir}/alternatives/servlet ]; then
        # %{_sysconfdir}/alternatives/servlet was removed on uninstall.
        # Create a broken symlink to make sure update-alternatives works correctly and falls back
        # to servletapi5 or servletapi4 if they're installed.
        ln -s %{_javadir}/%{name}-servlet-%{servletspec}-api.jar %{_sysconfdir}/alternatives/servlet
    fi
    update-alternatives --remove servlet \
        %{_javadir}/%{name}-servlet-%{servletspec}-api.jar
fi

%post lib
# those links are no longer needed
rm -f \
    %{libdir}/\[commons-collections-tomcat5\].jar \
    %{libdir}/\[commons-dbcp-tomcat5\].jar \
    %{libdir}/\[commons-pool-tomcat5\].jar \
    %{libdir}/\[ecj\].jar >/dev/null 2>&1

%post webapps
chown -R tomcat:tomcat %{tomcatappdir}/examples/META-INF
runuser -u tomcat -g tomcat -- xsltproc --output %{tomcatappdir}/examples/META-INF/context.xml %{confdir}/allowLinking.xslt %{tomcatappdir}/examples/META-INF/context.xml
if [ ! -e %{_datadir}/%{name}/webapps/examples ]; then
    ln -sf %{tomcatappdir}/examples %{_datadir}/%{name}/webapps/examples
fi
#use the same context.xml for sample war
mkdir -p %{tomcatappdir}/ROOT/META-INF
chown -R tomcat:tomcat %{tomcatappdir}/ROOT/META-INF
runuser -u tomcat -g tomcat -- xsltproc --output %{tomcatappdir}/ROOT/META-INF/context.xml %{confdir}/allowLinking.xslt %{tomcatappdir}/examples/META-INF/context.xml
if [ ! -e %{_datadir}/%{name}/webapps/ROOT ]; then
    ln -sf  %{tomcatappdir}/ROOT %{_datadir}/%{name}/webapps/ROOT
fi
#use the same context.xml for sample war
mkdir -p %{tomcatappdir}/webapps/sample/META-INF
chown -R tomcat:tomcat %{tomcatappdir}/sample/META-INF
runuser -u tomcat -g tomcat -- xsltproc --output %{tomcatappdir}/sample/META-INF/context.xml %{confdir}/allowLinking.xslt %{tomcatappdir}/examples/META-INF/context.xml
if [ ! -e %{_datadir}/%{name}/webapps/sample ]; then
    ln -sf %{tomcatappdir}/sample  %{_datadir}/%{name}/webapps/sample
fi

%postun webapps
if [ $1 -eq 0 ]; then # uninstall only
    rm %{tomcatappdir}/ROOT/META-INF/context.xml
    rm %{tomcatappdir}/sample/META-INF/context.xml
fi

%post admin-webapps
chown -R tomcat:tomcat %{tomcatappdir}/manager/META-INF
runuser -u tomcat -g tomcat -- xsltproc --output %{tomcatappdir}/manager/META-INF/context.xml %{confdir}/allowLinking.xslt %{tomcatappdir}/manager/META-INF/context.xml
if [ ! -e %{_datadir}/%{name}/webapps/manager ]; then
    ln -sf %{tomcatappdir}/manager %{_datadir}/%{name}/webapps/manager
fi

chown -R tomcat:tomcat %{tomcatappdir}/host-manager/META-INF
runuser -u tomcat -g tomcat -- xsltproc --output %{tomcatappdir}/host-manager/META-INF/context.xml %{confdir}/allowLinking.xslt %{tomcatappdir}/host-manager/META-INF/context.xml
if [ ! -e %{_datadir}/%{name}/webapps/host-manager ]; then
    ln -sf %{tomcatappdir}/host-manager %{_datadir}/%{name}/webapps/host-manager
fi

%post docs-webapp
chown -R tomcat:tomcat %{tomcatappdir}/docs/META-INF
runuser -u tomcat -g tomcat -- xsltproc --output %{tomcatappdir}/docs/META-INF/context.xml %{confdir}/allowLinking.xslt %{tomcatappdir}/docs/META-INF/context.xml
if [ ! -e %{_datadir}/%{name}/webapps/docs ]; then
    ln -sf %{tomcatappdir}/docs %{_datadir}/%{name}/webapps/docs
fi

%files
%doc {LICENSE,NOTICE,RELEASE*}
%{_bindir}/%{name}-digest
%{_bindir}/%{name}-tool-wrapper
%{_sbindir}/%{name}
%{_unitdir}/%{name}.service
%{_sbindir}/rc%{name}
%{_unitdir}/%{name}@.service
%dir %{_libexecdir}/%{name}
%dir %{_localstatedir}/lib/tomcats
%{_libexecdir}/%{name}/functions
%{_libexecdir}/%{name}/preamble
%{_libexecdir}/%{name}/server
#bnc#565901
%{bindir}/catalina.sh
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%dir %{basedir}
%dir %{confdir}
%attr(0775,root,tomcat) %dir %{appdir}
%attr(0770,tomcat,tomcat) %dir %{logdir}
%attr(0660,tomcat,tomcat) %{logdir}/catalina.out
%attr(0770,root,tomcat) %dir %{cachedir}
%attr(0775,root,tomcat) %dir %{cachedir}/Catalina

# tomcat group writtable dirs - bnc#625415
%attr(0770,root,tomcat) %dir %{tempdir}
%attr(0770,root,tomcat) %dir %{workdir}
%attr(0775,root,tomcat) %dir %{tomcatappdir}

%{confdir}/Catalina
%dir %{confdir}/conf.d
%{confdir}/conf.d/README
%config(noreplace) %{confdir}/%{name}.conf
%config(noreplace) %{confdir}/*.policy
%config(noreplace) %{confdir}/*.properties
%config(noreplace) %{confdir}/context.xml
%config(noreplace) %{confdir}/server.xml
# keep tomcat-users.xml readable only by root and tomcat group
%attr(0640,root,tomcat) %config(noreplace) %{confdir}/tomcat-users.xml
%config(noreplace) %{confdir}/web.xml
%config(noreplace) %{confdir}/jaspic-providers.xml
%dir %{homedir}
%{bindir}/bootstrap.jar
%{bindir}/catalina-tasks.xml
%{homedir}/lib
%{homedir}/temp
%{homedir}/work
%{homedir}/webapps
%{homedir}/logs
%{homedir}/conf
%{_fillupdir}/sysconfig.%{name}
%{confdir}/allowLinking.xslt
%{confdir}/valve.xslt

%files admin-webapps
%defattr(0644,root,tomcat,0755)
%{tomcatappdir}/host-manager
%config(noreplace) %{tomcatappdir}/host-manager/META-INF/context.xml
%{tomcatappdir}/manager
%config(noreplace) %{tomcatappdir}/manager/META-INF/context.xml

%files docs-webapp
%{tomcatappdir}/docs

%files el-3_0-api -f output/dist/src/res/maven/.mfiles-el-api
%{_javadir}/%{name}-el-%{elspec}-api.jar
%{_javadir}/%{name}-el-api.jar
%{libdir}/%{name}-el-%{elspec}-api.jar
%{_javadir}/%{name}-el_1_0_api.jar
%{_javadir}/%{name}-el_api.jar
%ghost %{_sysconfdir}/alternatives/el_1_0_api
%ghost %{_sysconfdir}/alternatives/el_api

%files javadoc
%doc %{_javadocdir}/%{name}

%files jsp-2_3-api -f output/dist/src/res/maven/.mfiles-jsp-api
%{_javadir}/%{name}-jsp-%{jspspec}-api.jar
%{_javadir}/%{name}-jsp-api.jar
%{_javadir}/%{name}-jsp.jar
%ghost %{_sysconfdir}/alternatives/jsp

%files lib -f output/dist/src/res/maven/.mfiles
%{libdir}
%dir %{bindir}
%{bindir}/tomcat-juli.jar
%exclude %{libdir}/%{name}-el-%{elspec}-api.jar
%exclude %{libdir}/%{name}*-embed-*.jar
# bnc#418664
%dir %{_sysconfdir}/ant.d
%config(noreplace) %{_sysconfdir}/ant.d/catalina-ant

%files embed -f output/dist/src/res/maven/.mfiles-embed
%dir %{libdir}

%files servlet-4_0-api -f output/dist/src/res/maven/.mfiles-servlet-api
%license LICENSE
%{_javadir}/%{name}-servlet-%{servletspec}-api.jar
%{_javadir}/%{name}-servlet-api.jar
%{_javadir}/%{name}-servlet.jar
%{_javadir}/servlet.jar
%ghost %{_sysconfdir}/alternatives/servlet

%files webapps
%defattr(0644,root,tomcat,0755)
#bnc#520532
%config(noreplace) %{tomcatappdir}/ROOT
%{tomcatappdir}/examples
%config(noreplace) %{tomcatappdir}/examples/META-INF/context.xml
%{tomcatappdir}/sample

%files jsvc
%defattr(755,root,root,0755)
%{_unitdir}/%{name}-jsvc.service
%{_sbindir}/rc%{name}-jsvc

%changelog
* Tue Jun 24 2025 Michele Bussolotto <michele.bussolotto@suse.com>
- Update to Tomcat 9.0.106
  * Fixed CVEs:
    + CVE-2025-46701: refactor CGI servlet to access resources via
    WebResources (bsc#1243815)
    + CVE-2025-48988: limits the total number of parts in a
    multi-part request and limits the size of
    the headers provided with each part (bsc#1244656)
    + CVE-2025-49125: Expand checks for webAppMount (bsc#1244649)
  * Catalina
    + Add: Support for the java:module namespace which mirrors the
    java:comp namespace.
    + Add: Support parsing of multiple path parameters separated by ; in a
    single URL segment. Based on pull request #860 by Chenjp.
    + Add: Support for limiting the number of parameters in HTTP requests
    through the new ParameterLimitValve. The valve allows configurable
    URL-specific limits on the number of parameters.
    + Fix: 69699: Encode redirect URL used by the rewrite valve with the
    session id if appropriate, and handle cross context with different
    session configuration when using rewrite.
    + Add: #863: Support for comments at the end of lines in text rewrite
    map files to align behaviour with Apache httpd. Pull request
    provided by Chenjp.
    + Fix: 69706: Saved request serialization issue in FORM introduced
    when allowing infinite session timeouts.
    + Fix: Expand the path checks for Pre-Resources and Post-Resources
    mounted at a path within the web application.
    + Fix: 69588: Enable allowLinking to be set on PreResources,
    JarResources and PostResources. If not set explicitly, the setting
    will be inherited from the Resources.
    + Add: 69633: Support for Filters using context root mappings.
    + Fix: #843: Off by one validation logic for partial PUT ranges and
    associated test case. Submitted by Chenjp.
    + Refactor: Replace the unused buffer in
    org.apache.catalina.connector.InputBuffer with a static, zero
    length buffer.
    + Refactor: GCI servlet to access resources via the WebResource API.
    + Fix: 69662: Report name in exception message when a naming lookup
    failure occurs. Based on code submitted by Donald Smith.
    + Fix: Ensure that the FORM authentication attribute
    authenticationSessionTimeout works correctly when sessions have an
    infinite timeout when authentication starts.
    + Add: Provide a content type based on file extension when web
    application resources are accessed via a URL.
  * Coyote
    + Refactor: #861: TaskQueue to use the new interface RetryableQueue
    which enables better integration of custom Executors which provide
    their own BlockingQueue implementation. Pull request provided by
    Paulo Almeida.
    + Add: Finer grained control of multi-part request processing via two
    new attributes on the Connector element. maxPartCount limits the
    total number of parts in a multi-part request and maxPartHeaderSize
    limits the size of the headers provided with each part. Add support
    for these new attributes to the ParameterLimitValve.
    + Refactor: The SavedRequestInputFilter so the buffered data is used
    directly rather than copied.
  * Jasper
    + Fix: 69696: Mark the JSP wrapper for reload after a failed
    compilation.
    + Fix: 69635: Add support to javax.el.ImportHandler for resolving
    inner classes.
    + Add: #842: Support for optimized execution of c:set and c:remove
    tags, when activated via JSP servlet param
    useNonstandardTagOptimizations.
    + Fix: An edge case compilation bug for JSP and tag files on case
    insensitive file systems that was exposed by the test case for
    69635.
  * Web applications
    + Fix: 69694: Improve error reporting of deployment tasks done using
    the manager webapp when a copy operation fails.
    + Add: 68876: Documentation. Update the UML diagrams for server
    start-up, request processing and authentication using PlantUML and
    include the source files for each diagram.
  * Other
    + Add: Thread name to webappClassLoader.stackTraceRequestThread
    message. Patch provided by Felix Zhang.
    + Update: The internal fork of Apache Commons FileUpload to 1.6.0-RC1
    (2025-06-05).
    + Update: EasyMock to 5.6.0.
    + Update: Checkstyle to 10.25.0.
    + Fix: #858: Extend improvements to CVE-2024-56337 protection to
    service.bat. Pull request provided by Markus Hoffrogge.
    + Fix: Use the full path when the installer for Windows sets calls
    icacls.exe to set file permissions.
    + Update: Improvements to Japanese translations provided by tak7iji.
    + Update: Jacoco to 0.8.13.
    + Code: Explicitly set the locale to be used for Javadoc. For
    official releases, this locale will be English (US) to support
    reproducible builds.
    + Update: Byte Buddy to 1.17.5.
    + Update: Checkstyle to 10.23.1.
    + Update: File extension to media type mappings to align with the
    current list used by the Apache Web Server (httpd).
    + Update: Improvements to French translations.
    + Update: Improvements to Japanese translations provided by tak7iji.
* Wed May  7 2025 Michele Bussolotto <michele.bussolotto@suse.com>
- Hardening permissions (bsc#1242722)
* Fri May  2 2025 Fridrich Strba <fstrba@suse.com>
- Make conflicts and provides more generic
* Wed Apr 30 2025 Michele Bussolotto <michele.bussolotto@suse.com>
- Update to Tomcat 9.0.104
  * Fixed CVEs:
    + CVE-2025-31650: invalid priority field values should be ignored
    (bsc#1242008)
    + CVE-2025-31651: Better handling of URLs with literal ';' and '?'
    (bsc#1242009)
  * Catalina
    + Fix: Fix use of SSS in SimpleDateFormat pattern for AccessLogValve.
    (rjung)
    + Fix: Process possible path parameters rewrite production in the rewrite
    valve. (remm)
    + Fix: 69643: Optimize directory listing for large amount of files. Patch
    submitted by Loic de l'Eprevier. (remm)
    + Fix: Return 400 if the amount of content sent for a partial PUT is
    inconsistent with the range that was specified. (remm)
    + Add: Add a new RateLimiter implementation,
    org.apache.catalina.util.ExactRateLimiter, that can be used with
    org.apache.catalina.filters.RateLimitFilter to provide rate limit based
    on the exact values configured. Based on pull request #794 by Chenjp.
    (markt)
    + Fix: Fix parsing of the time-taken token in the ExtendedAccessLogValve.
    (remm)
    + Fix: Fix invocation of the FFM OpenSSL code for setting a SSL engine and
    FIPS mode. (remm)
    + Fix: 69600: Add IPv6 local addresses (RFC 4193 and RFC 4291) to the
    default internal proxies for the RemoteIpFilter and RemoteIpValve.
    (markt)
    + Fix: 69615: Improve integration with the not found class resources cache
    for users who are using a custom web application class loader and/or
    using reflection to dynamically add external repositories to the web
    application class loader. (markt)
    + Add: Add a new initialisation parameter to the Default servlet -
    allowPostAsGet - which controls whether a direct request (i.e. not a
    forward or an include) for a static resource using the POST method will
    be processed as if the GET method had been used. If not allowed, the
    request will be rejected. The default behaviour of processing the request
    as if the GET method had been used is unchanged. (markt)
    + Fix: 69623: Correct a long standing regression that meant that calls to
    ClassLoader.getResource().getContent() failed when made from within a web
    application with resource caching enabled. (markt)
    + Fix: 69634: Avoid NPE on JsonErrorReportValve. (remm)
    + Fix: Add missing throwable stack trace to JsonErrorReportValve equivalent
    to the one from ErrorReportValve. (remm)
    + Fix: Improve the handling of %%nn URL encoding in the RewriteValve and
    document how %%nn URL encoding may be used with rewrite rules. (markt)
    + Fix: Fix a potential exception when calling
    WebappClassLoaderBase.getResource(""). (markt)
  * Coyote
    + Fix: 69607: Allow failed initialization of MD5. Based on code submitted
    by Shivam Verma. (remm)
    + Fix: 69614: HTTP/2 priority frames with an invalid priority field value
    should be ignored. (markt)
    + Fix: Improve handling of unexpected errors during HTTP/2 processing.
    (markt)
    + Fix: Add missing code to process an OpenSSL profile, such as PROFILE=
    SYSTEM, using FFM. (remm)
    + Add: Simplify the process of using a custom SSLContext for an HTTPS
    enabled connector. Based on pull request #805 by Hakky54. (markt)
  * Jasper
    + Code: Replace custom URL encoding provided by the JSP runtime library
    with calls to java.net.URLEncoder.encode(). (markt)
    + Add: Add compiler using the Java Compiler API, supporting exploded web
    applications. The compilerClassName to use is
    org.apache.jasper.compiler.JavaCompiler. (remm)
    + Add: Add support for specifying Java 25 (with the value 25) as the
    compiler source and/or compiler target for JSP compilation. If used with
    an Eclipse JDT compiler version that does not support these values, a
    warning will be logged and the default will be used. (markt)
  * Cluster
    + Fix: Fix resetting cross context sessions in the ReplicationValve.
    (remm)
  * Web applications
    + Add: Documentation. Add a link to the Log4j documentation that describes
    how to use Log4j rather than JULI for Tomcat's internal logging. (markt)
    + Add: Documentation. Document the runtime attributes available to web
    applications via the Request or the ServletContext. Based on pull request
    [#832] by usmazat. (markt)
  * Other
    + Fix: Set sun.io.useCanonCaches in service.bat. Based on pull request
    [#841] by Paul Lodge. (remm)
    + Fix: The minimum Java version to build a release is now Java 22,
    mirroring Tomcat 10.1. This removes the need for using a java-ffm.home
    property. (remm)
    + Update: Revert JSign to 6.0 to avoid a file locking issue. (markt)
    + Update: Update to NSIS 3.11. (markt)
    + Update: Update to ByteBuddy 1.17.4. (markt)
    + Update: Update to Checkstyle 10.21.4. (markt)
    + Update: Update to SpotBugs to 4.9.3. (markt)
    + Update: Improvements to French translations. (remm)
    + Update: Improvements to Japanese translations provided by tak7iji. (markt)
* Tue Mar 18 2025 Ricardo Mestre <ricardo.mestre@suse.com>
- Update to Tomcat 9.0.102
  * Fixes:
    + launch with java 17 (bsc#1239676)
  * Catalina
    + Fix: Weak etags in the If-Range header should not match as strong etags
    are required. (remm)
    + Fix: When looking up class loader resources by resource name, the resource
    name should not start with '/'. If the resource name does start with '/',
    Tomcat is lenient and looks it up as if the '/' was not present. When the
    web application class loader was configured with external repositories and
    names starting with '/' were used for lookups, it was possible that cached
    'not found' results could effectively hide lookup results using the
    correct resource name. (markt)
    + Fix: Enable the JNDIRealm to validate credentials provided to
    HttpServletRequest.login(String username, String password) when the realm
    is configured to use GSSAPI authentication. (markt)
    + Fix: Fix a bug in the JRE compatibility detection that incorrectly
    identified Java 19 and Java 20 as supporting Java 21 features. (markt)
    + Fix: Improve the checks for exposure to and protection against
    CVE-2024-56337 so that reflection is not used unless required. The checks
    for whether the file system is case sensitive or not have been removed.
    (markt)
    + Fix: Avoid scenarios where temporary files used for partial PUT would not
    be deleted. (remm)
    + Fix: 69602: Fix regression in releases from 12-2024 that were too strict
    and rejected weak etags in the If-Range header. (remm)
    + Fix: 69576: Avoid possible failure initializing JreCompat due to uncaught
    exception introduced for the check for CVE-2024-56337. (remm)
  * Cluster
    + Add: 69598: Add detection of service account token changes to the
    KubernetesMembershipProvider implementation and reload the token if it
    changes. Based on a patch by Miroslav Jezbera. (markt)
  * Coyote
    + Fix: 69575: Avoid using compression if a response is already compressed
    using compress, deflate or zstd. (remm)
    + Update: Use Transfer-Encoding for compression rather than Content-Encoding
    if the client submits a TE header containing gzip. (remm)
    + Fix: Fix a race condition in the handling of HTTP/2 stream reset that
    could cause unexpected 500 responses. (markt)
  * Other
    + Add: Add makensis as an option for building the Installer for Windows on
    non-Windows platforms. (rjung/markt)
    + Update: Update Byte Buddy to 1.17.1. (markt)
    + Update: Update Checkstyle to 10.21.3. (markt)
    + Update: Update SpotBugs to 4.9.1. (markt)
    + Update: Update JSign to 7.1. (markt)
    + Add: Improvements to French translations. (remm)
    + Add: Improvements to Japanese translations by tak7iji. (markt)
    + Add: Add org.apache.juli.JsonFormatter to format log as one line JSON
    documents. (remm)
* Wed Mar 12 2025 Ricardo Mestre <ricardo.mestre@suse.com>
- Update to Tomcat 9.0.99
  * Fixed CVE:
    + CVE-2025-24813: potential RCE and/or information disclosure/corruption with
    partial PUT (bsc#1239302)
  * Catalina
    + Update: Add tableName configuration on the DataSourcePropertyStore that
    may be used by the WebDAV Servlet. (remm)
    + Update: Improve HTTP If headers processing according to RFC 9110. Based on
    pull request #796 by Chenjp. (remm/markt)
    + Update: Allow readOnly attribute configuration on the Resources element
    and allow configure the readOnly attribute value of the main resources.
    The attribute value will also be used by the default and WebDAV Servlets.
    (remm)
    + Fix: 69285: Optimise the creation of the parameter map for included
    requests. Based on sample code and test cases provided by John
    Engebretson. (markt)
    + Fix: 69527: Avoid rare cases where a cached resource could be set with 0
    content length, or could be evicted immediately. (remm)
    + Fix: Fix possible edge cases (such as HTTP/1.0) with trying to detect
    requests without body for WebDAV LOCK and PROPFIND. (remm)
    + Fix: 69528: Add multi-release JAR support for the bloom
    archiveIndexStrategy of the Resources. (remm)
    + Fix: Improve checks for WEB-INF and META-INF in the WebDAV servlet. Based
    on a patch submitted by Chenjp. (remm)
    + Add: Add a check to ensure that, if one or more web applications are
    potentially vulnerable to CVE-2024-56337, the JVM has been configured to
    protect against the vulnerability and to configure the JVM correctly if
    not. Where one or more web applications are potentially vulnerable to
    CVE-2024-56337 and the JVM cannot be correctly configured or it cannot be
    confirmed that the JVM has been correctly configured, prevent the impacted
    web applications from starting. (markt)
    + Fix: Remove unused session to client map from CrawlerSessionManagerValve.
    Submitted by Brian Matzon. (remm)
    + Fix: When using the WebDAV servlet with serveSubpathOnly set to true,
    ensure that the destination for any requested WebDAV operation is also
    restricted to the sub-path. (markt)
    + Fix: Generate an appropriate Allow HTTP header when the Default servlet
    returns a 405 (method not allowed) response in response to a DELETE
    request because the target resource cannot be deleted. Pull request #802
    provided by Chenjp. (markt)
    + Code: Refactor creation of RequestDispatcher instances so that the
    processing of the provided path is consistent with normal request
    processing. (markt)
    + Add: Add encodedReverseSolidusHandling and encodedSolidusHandling
    attributes to Context to provide control over the handling of the path
    used to created a RequestDispatcher. (markt)
    + Fix: Handle a potential NullPointerException after an IOException occurs
    on a non-container thread during asynchronous processing. (markt)
    + Fix: Enhance lifecycle of temporary files used by partial PUT. (remm)
  * Coyote
    + Fix: Don't log warnings for registered HTTP/2 settings that Tomcat does
    not support. These settings are now silently ignored. (markt)
    + Fix: Avoid a rare NullPointerException when recycling the
    Http11InputBuffer. (markt)
    + Fix: Lower the log level to debug for logging an invalid socket channel
    when processing poller events for the NIO Connector as this may occur in
    normal usage. (markt)
    + Code: Clean-up references to the HTTP/2 stream once request processing has
    completed to aid GC and reduce the size of the HTTP/2 recycled request and
    response cache. (markt)
    + Add: Add a new Connector configuration attribute,
    encodedReverseSolidusHandling, to control how %%5c sequences in URLs are
    handled. The default behaviour is unchanged (decode) keeping in mind that
    the allowBackslash attribute determines how the decoded URI is processed.
    (markt)
    + Fix: 69545: Improve CRLF skipping for the available method of the
    ChunkedInputFilter. (remm)
    + Fix: Improve the performance of repeated calls to getHeader(). Pull
    request #813 provided by Adwait Kumar Singh. (markt)
    + Fix: 69559: Ensure that the Java 24 warning regarding the use of
    sun.misc.Unsafe::invokeCleaner is only reported by the JRE when the code
    will be used. (markt)
  * Jasper
    + Fix: 69508: Correct a regression in the fix for 69382 that broke JSP
    include actions if both the page attribute and the body contained
    parameters. Pull request #803 provided by Chenjp. (markt)
    + Fix: 69521: Update the EL Parser to allow the full range of valid
    characters in an EL identifier as defined by the Java Language
    Specification. (markt)
    + Fix: 69532: Optimise the creation of ExpressionFactory instances. Patch
    provided by John Engebretson. (markt)
  * Web applications
    + Add: Documentation. Expand the description of the security implications of
    setting mapperContextRootRedirectEnabled and/or
    mapperDirectoryRedirectEnabled to true. (markt)
    + Fix: Documentation. Better document the default for the truststoreProvider
    attribute of a SSLHostConfig element. (markt)
  * Other
    + Update: Update to Commons Daemon 1.4.1. (markt)
    + Update: Update the internal fork of Commons Pool to 2.12.1. (markt)
    + Update: Update Byte Buddy to 1.16.1. (markt)
    + Update: Update UnboundID to 7.0.2. (markt)
    + Update: Update Checkstyle to 10.21.2. (markt)
    + Update: Update SpotBugs to 4.9.0. (markt)
    + Add: Improvements to French translations. (remm)
    + Add: Improvements to Chinese translations by leeyazhou. (markt)
    + Add: Improvements to Japanese translations by tak7iji. (markt)
* Fri Jan  3 2025 Ricardo Mestre <ricardo.mestre@suse.com>
- Update to Tomcat 9.0.98
  * Fixed CVEs:
    + CVE-2024-54677: DoS in examples web application (bsc#1234664)
    + CVE-2024-50379: RCE due to TOCTOU issue in JSP compilation (bsc#1234663)
    + CVE-2024-52317: Request/response mix-up with HTTP/2 (bsc#1233435)
  * Catalina
    + Add: Add option to serve resources from subpath only with WebDAV Servlet
    like with DefaultServlet. (michaelo)
    + Fix: Add special handling for the protocols attribute of SSLHostConfig in
    storeconfig. (remm)
    + Fix: 69442: Fix case sensitive check on content-type when parsing request
    parameters. (remm)
    + Code: Refactor duplicate code for extracting media type and subtype from
    content-type into a single method. (markt)
    + Fix: Compatibility of generated embedded code with components where
    constructors or property related methods throw a checked exception. (remm)
    + Fix: The previous fix for inconsistent resource metadata during concurrent
    reads and writes was incomplete. (markt)
    + Fix: 69444: Ensure that the javax.servlet.error.message request attribute
    is set when an application defined error page is called. (markt)
    + Fix: Avoid quotes for numeric values in the JSON generated by the status
    servlet. (remm)
    + Add: Add strong ETag support for the WebDAV and default servlet, which can
    be enabled by using the useStrongETags init parameter with a value set to
    true. The ETag generated will be a SHA-1 checksum of the resource content.
    (remm)
    + Fix: Use client locale for directory listings. (remm)
    + Fix: 69439: Improve the handling of multiple Cache-Control headers in the
    ExpiresFilter. Based on pull request #777 by Chenjp. (markt)
    + Fix: 69447: Update the support for caching classes the web application
    class loader cannot find to take account of classes loaded from external
    repositories. Prior to this fix, these classes could be incorrectly marked
    as not found. (markt)
    + Fix: 69466: Rework handling of HEAD requests. Headers explicitly set by
    users will not be removed and any header present in a HEAD request will
    also be present in the equivalent GET request. There may be some headers,
    as per RFC 9110, section 9.3.2, that are present in a GET request that are
    not present in the equivalent HEAD request. (markt)
    + Fix: 69471: Log instances of CloseNowException caught by
    ApplicationDispatcher.invoke() at debug level rather than error level as
    they are very likely to have been caused by a client disconnection or
    similar I/O issue. (markt)
    + Add: Add a test case for the fix for 69442. Also refactor references to
    application/x-www-form-urlencoded. Based on pull request #779 by Chenjp.
    (markt)
    + Fix: 69476: Catch possible ISE when trying to report PUT failure in the
    DefaultServlet. (remm)
    + Add: Add support for RateLimit header fields for HTTP (draft) in the
    RateLimitFilter. Based on pull request #775 provided by Chenjp. (markt)
    + Add: #787: Add regression tests for 69478. Pull request provided by Thomas
    Krisch. (markt)
    + Fix: The default servlet now rejects HTTP range requests when two or more
    of the requested ranges overlap. Based on pull request #782 provided by
    Chenjp. (markt)
    + Fix: Enhance Content-Range verification for partial PUT requests handled
    by the default servlet. Provided by Chenjp in pull request #778. (markt)
    + Fix: Harmonize DataSourceStore lookup in the global resources to
    optionally avoid the comp/env prefix which is usually not used there.
    (remm)
    + Fix: As required by RFC 9110, the HTTP Range header will now only be
    processed for GET requests. Based on pull request #790 provided by Chenjp.
    (markt)
    + Fix: Deprecate the useAcceptRanges initialisation parameter for the
    default servlet. It will be removed in Tomcat 12 onwards where it will
    effectively be hard coded to true. (markt)
    + Add: Add DataSource based property storage for the WebdavServlet. (remm)
  * Coyote
    + Fix: Align encodedSolidusHandling with the Servlet specification. If the
    pass-through mode is used, any %%25 sequences will now also be passed
    through to avoid errors and/or corruption when the application decodes the
    path. (markt)
  * Jasper
    + Fix: Further optimise EL evaluation of method parameters. Patch provided
    by Paolo B. (markt)
    + Fix: Follow-up to the fix for 69381. Apply the optimisation for method
    lookup performance in expression language to an additional location.
    (markt)
  * Web applications
    + Fix: Documentation. Remove references to the ResourceParams element.
    Support for ResourceParams was removed in Tomcat 5.5.x. (markt)
    + Fix: Documentation. 69477: Correct name of attribute for RemoteIPFilter.
    The attribute is internalProxies rather than allowedInternalProxies. Pull
    request #786 provided by Jorge Díaz. (markt)
    + Fix: Examples. Fix broken links when Servlet Request Info example is
    called via a URL that includes a pathInfo component. (markt)
    + Fix: Examples. Expand the obfuscation of session cookie values in the
    request header example to JSON responses. (markt)
    + Add: Examples. Add the ability to delete session attributes in the servlet
    session example. (markt)
    + Add: Examples. Add a hard coded limit of 10 attributes per session for the
    servlet session example. (markt)
    + Add: Examples. Add the ability to delete session attributes and add a hard
    coded limit of 10 attributes per session for the JSP form authentication
    example. (markt)
    + Add: Examples. Limit the shopping cart example to only allow adding the
    pre-defined items to the cart. (markt)
    + Fix: Examples. Remove JSP calendar example. (markt)
  * Other
    + Fix: 69465: Fix warnings during native image compilation using the Tomcat
    embedded JARs. (markt)
    + Update: Update Tomcat's fork of Commons DBCP to 2.13.0. (markt)
    + Update: Update EasyMock to 5.5.0. (markt)
    + Update: Update Checkstyle to 10.20.2. (markt)
    + Update: Update BND to 7.1.0. (markt)
    + Add: Improvements to French translations. (remm)
    + Add: Improvements to Korean translations. (markt)
    + Add: Improvements to Chinese translations. (markt)
    + Add: Improvements to Japanese translations by tak7iji. (markt)
- Modified patch:
  * tomcat-9.0-jdt.patch
    + rediff
* Fri Nov 22 2024 Michele Bussolotto <michele.bussolotto@suse.com>
- Update to Tomcat 9.0.97
  * Fixed CVEs:
    + CVE-2024-52316: If the Jakarta Authentication fails with an exception,
    set a 500 status (bsc#1233434)
  * Catalina
    + Add: Add support for the new Servlet API method
    HttpServletResponse.sendEarlyHints(). (markt)
    + Add: 55470: Add debug logging that reports the class path when a
    ClassNotFoundException occurs in the digester or the web application
    class loader. Based on a patch by Ralf Hauser. (markt)
    + Update: 69374: Properly separate between table header and body in
    DefaultServlet's listing. (michaelo)
    + Update: 69373: Make DefaultServlet's HTML listing file last modified
    rendering better (flexible). (michaelo)
    + Update: Improve HTML output of DefaultServlet. (michaelo)
    + Code: Refactor RateLimitFilter to use FilterBase as the base class. The
    primary advantage for doing this is less code to process init-param
    values. (markt)
    + Update: 69370: DefaultServlet's HTML listing uses incorrect labels.
    (michaelo)
    + Fix: Avoid NPE in CrawlerSessionManagerValve for partially mapped
    requests. (remm)
    + Fix: Add missing WebDAV Lock-Token header in the response when locking
    a folder. (remm)
    + Fix: Invalid WebDAV lock requests should be rejected with 400. (remm)
    + Fix: Fix regression in WebDAV when attempting to unlock a collection.
    (remm)
    + Fix: Verify that destination is not locked for a WebDAV copy operation.
    (remm)
    + Fix: Send 415 response to WebDAV MKCOL operations that include a
    request body since this is optional and unsupported. (remm)
    + Fix: Enforce DAV: namespace on WebDAV XML elements. (remm)
    + Fix: Do not allow a new WebDAV lock on a child resource if a parent
    collection is locked (RFC 4918 section 6.1). (remm)
    + Fix: WebDAV Delete should remove any existing lock on successfully
    deleted resources. (remm)
    + Update: Remove WebDAV lock null support in accordance with RFC 4918
    section 7.3 and annex D. Instead, a lock on a non-existing resource
    will create an empty file locked with a regular lock. (remm)
    + Update: Rewrite implementation of WebDAV shared locks to comply with
    RFC 4918. (remm)
    + Update: Implement WebDAV If header using code from the Apache Jackrabbit
    project. (remm)
    + Add: Add PropertyStore interface in the WebDAV Servlet, to allow
    implementation of dead properties storage. The store used can be
    configured using the 'propertyStore' init parameter of the WebDAV
    servlet. A simple non-persistent implementation is used if no custom
    store is configured. (remm)
    + Update: Implement WebDAV PROPPATCH method using the newly added
    PropertyStore. (remm)
    + Fix: Cache not found results when searching for web application class
    loader resources. This addresses performance problems caused by
    components such as java.sql.DriverManager which, in some circumstances,
    will search for the same class repeatedly. In a large web application
    this can cause performance problems. The size of the cache can be
    controlled via the new notFoundClassResourceCacheSize on the
    StandardContext. (markt)
    + Fix: Stop after INITIALIZED state should be a noop since it is possible
    for subcomponents to be in FAILED after init. (remm)
    + Fix: Fix incorrect web resource cache size calculations when there are
    concurrent PUT and DELETE requests for the same resource. (markt)
    + Add: Add debug logging for the web resource cache so the current size
    can be tracked as resources are added and removed. (markt)
    + Update: Replace legacy WebDAV opaquelocktoken: scheme for lock tokens
    with urn:uuid: as recommended by RFC 4918, and remove secret init
    parameter. (remm)
    + Fix: Concurrent reads and writes (e.g. GET and PUT / DELETE) for the
    same path caused corruption of the FileResource where some of the
    fields were set as if the file exists and some as set as if it does
    not. This resulted in inconsistent metadata. (markt)
    + Fix: 69415: Ensure that the ExpiresFilter only sets cache headers on
    GET and HEAD requests. Also skip requests where the application has set
    Cache-Control: no-store. (markt)
    + Fix: 69419: Improve the performance of ServletRequest.getAttribute()
    when there are multiple levels of nested includes. Based on a patch
    provided by John Engebretson. (markt)
    + Add: All applications to send an early hints informational response by
    calling HttpServletResponse.sendError() with a status code of 103.
    (schultz)
    + Fix: Ensure that the Jakarta Authentication CallbackHandler only
    creates one GenericPrincipal in the Subject. (markt)
    + Fix: If the Jakarta Authentication process fails with an Exception,
    explicitly set the HTTP response status to 500 as the ServerAuthContext
    may not have set it. (markt)
    + Fix: When persisting the Jakarta Authentication provider configuration,
    create any necessary parent directories that don't already exist.
    (markt)
    + Fix: Correct the logic used to detect errors when deleting temporary
    files associated with persisting the Jakarta Authentication provider
    configuration. (markt)
    + Fix: When processing Jakarta Authentication callbacks, don't overwrite
    a Principal obtained from the PasswordValidationCallback with null if
    the CallerPrincipalCallback does not provide a Principal. (markt)
    + Fix: Avoid store config backup loss when storing one configuration more
    than once per second. (remm)
    + Fix: 69359: WebdavServlet duplicates getRelativePath() method from
    super class with incorrect Javadoc. (michaelo)
    + Fix: 69360: Inconsistent DELETE behavior between WebdavServlet and
    DefaultServlet. (michaelo)
    + Fix: Make WebdavServlet properly return the Allow header when deletion
    of a resource is not allowed. (michaelo)
    + Fix: Add log warning if non wildcard mappings are used with the
    WebdavServlet. (remm)
    + Fix: 69361: Ensure that the order of entries in a multi-status response
    to a WebDAV is consistent with the order in which resources were
    processed. (markt)
    + Fix: 69362: Provide a better multi-status response when deleting a
    collection via WebDAV fails. Empty directories that cannot be deleted
    will now be included in the response. (markt)
    + Fix: 69363: Use getPathPrefix() consistently in the WebDAV servlet to
    ensure that the correct path is used when the WebDAV servlet is mounted
    at a sub-path within the web application. (markt)
    + Fix: Improve performance of ApplicationHttpRequest.parseParameters().
    Based on sample code and test cases provided by John Engebretson.
    (markt)
    + Add: Add support for RFC 8297 (Early Hints). Applications can use
    this feature by casting the HttpServletResponse to
    org.apache.catalina.connector.Reponse and then calling the method
    void sendEarlyHints(). This method will be added to the Servlet API
    (removing the need for the cast) in Servlet 6.2 onwards. (markt)
    + Fix: 69214: Do not reject a CORS request that uses POST but does not
    include a content-type header. Tomcat now correctly processes this as
    a simple CORS request. Based on a patch suggested by thebluemountain.
    (markt)
    + Fix: Refactor SpnegoAuthenticator so it uses Subject.callAs() rather
    than Subject.doAs() when available. (markt)
  * Coyote
    + Fix: Return null SSL session id on zero length byte array returned from
    the SSL implementation. (remm)
    + Fix: Skip OpenSSLConf with BoringSSL since it is unsupported. (remm)
    + Fix: Create the HttpParser in Http11Processor if it is not present on
    the AbstractHttp11Protocol to provide better lifecycle robustness for
    regular HTTP/1.1. The new behavior was introduced on a previous
    refactoring to improve HTTP/2 performance. (remm)
    + Fix: OpenSSLContext will now throw a KeyManagementException if something
    is known to have gone wrong in the init method, which is the behavior
    documented by javax.net.ssl.SSLContext.init. This makes error handling
    more consistent. (remm)
    + Fix: 69316: Ensure that FastHttpDateFormat#getCurrentDate() (used to
    generate Date headers for HTTP responses) generates the correct string
    for the given input. Prior to this change, the output may have been
    wrong by one second in some cases. Pull request #751 provided by Chenjp.
    (markt)
    + Add: Add server and serverRemoveAppProvidedValues to the list of
    attributes the HTTP/2 protocol will inherit from the HTTP/1.1 connector
    it is nested within. (markt)
    + Fix: Avoid possible crashes when using Apache Tomcat Native, caused by
    destroying SSLContext objects through GC after APR has been terminated.
    (remm)
    + Fix: Improve HTTP/2 handling of trailer fields for requests. Trailer
    fields no longer need to be received before the headers of the
    subsequent stream nor are trailer fields for an in-progress stream
    swallowed if the Connector is paused before the trailer fields are
    received. (markt)
    + Fix: Ensure the request and response are not recycled too soon for an
    HTTP/2 stream when a stream level error is detected during the processing
    of incoming HTTP/2 frames. This could lead to incorrect processing times
    appearing in the access log. (markt)
    + Fix: Fix 69320, a regression in the fix for 69302 that meant the
    HTTP/2 processing was likely to be broken for all clients once any
    client sent an HTTP/2 reset frame. (markt)
    + Fix: Correct a regression in the fix for non-blocking reads of chunked
    request bodies that caused InputStream.available() to return a non-zero
    value when there was no data to read. In some circumstances this could
    cause a blocking read to block waiting for more data rather than return
    the data it had already received. (markt)
    + Add: Add a new attribute cookiesWithoutEquals to the Rfc6265CookieProcessor.
    The default behaviour is unchanged. (markt)
    + Fix: Ensure that Tomcat sends a TLS close_notify message after receiving
    one from the client when using the OpenSSLImplementation. (markt)
    + Fix: 69301: Fix trailer headers replacing non-trailer headers when writing
    response headers to the access log. Based on a patch and test case
    provided by hypnoce. (markt)
    + Fix: 69302: If an HTTP/2 client resets a stream before the request body is
    fully written, ensure that any ReadListener is notified via a call to
    ReadListener.onErrror(). (markt)
    + Fix: Correct regressions in the refactoring that added recycling of the
    coyote request and response to the HTTP/2 processing. (markt)
    + Add: Add OpenSSL integration using the FFM API rather than Tomcat Native.
    OpenSSL support may be enabled by adding the
    org.apache.catalina.core.OpenSSLLifecycleListener listener on the
    Server element when using Java 22 or later. (remm)
    + Fix: Ensure that HTTP/2 stream input buffers are only created when there
    is a request body to be read. (markt)
    + Code: Refactor creation of HttpParser instances from the Processor level
    to the Protocol level since the parser configuration depends on the
    protocol and the parser is, otherwise, stateless. (markt)
    + Add: Align HTTP/2 with HTTP/1.1 and recycle the container internal
    request and response processing objects by default. This behaviour can
    be controlled via the new discardRequestsAndResponses attribute on the
    HTTP/2 upgrade protocol. (markt)
  * Jasper
    + Fix: Add back tag release method as deprecated in the runtime for
    compatibility with old generated code. (remm)
    + Fix: 69399: Fix regression caused by the improvement 69333 which caused
    the tag release to be called when using tag pooling, and to be skipped
    when not using it. Patch submitted by Michal Sobkiewicz. (remm)
    + Fix: 69381: Improve method lookup performance in expression language.
    When the required method has no arguments there is no need to consider
    casting or coercion and the method lookup process can be simplified.
    Based on pull request #770 by John Engebretson.
    + Fix: 69382: Improve the performance of the JSP include action by
    re-using results of relatively expensive method calls in the generated
    code rather than repeating them. Patch provided by John Engebretson.
    (markt)
    + Fix: 69398: Avoid unnecessary object allocation in PageContextImpl.
    Based on a suggestion by John Engebretson. (markt)
    + Fix: 69406: When using StringInterpreterEnum, do not throw an
    IllegalArgumentException when an invalid Enum is encountered. Instead,
    resolve the value at runtime. Patch provided by John Engebretson.
    (markt)
    + Fix: 69429: Optimise EL evaluation of method parameters for methods
    that do not accept any parameters. Patch provided by John Engebretson.
    (markt)
    + Fix: 69333: Remove unnecessary code from generated JSPs. (markt)
    + Fix: 69338: Improve the performance of processing expressions that
    include AND or OR operations with more than two operands and expressions
    that use not empty. (markt)
    + Fix: 69348: Reduce memory consumption in ELContext by using lazy
    initialization for the data structure used to track lambda arguments.
    (markt)
    + Fix: Switch the TldScanner back to logging detailed scan results at debug
    level rather than trace level. (markt)
  * Web applications
    + Fix: The manager webapp will now be able to access certificates again
    when OpenSSL is used. (remm)
    + Fix: Documentation. Align the logging configuration documentation with
    the current defaults. (markt)
  * WebSocket
    + Fix: If a blocking message write exceeds the timeout, don't attempt the
    write again before throwing the exception. (markt)
    + Fix: An EncodeException being thrown during a message write should not
    automatically cause the connection to close. The application should
    handle the exception and make the decision whether or not to close the
    connection. (markt)
  * jdbc-pool
    + Fix: 69255: Correct a regression in the fix for 69206 that meant exceptions
    executing statements were wrapped in a java.lang.reflect.UndeclaredThrowableException
    rather than the application seeing the original SQLException. Fixed by
    pull request #744 provided by Michael Clarke. (markt)
    + Fix: 69279: Correct a regression in the fix for 69206 that meant that
    methods that previously returned a null ResultSet were returning a proxy
    with a null delegate. Fixed by pull request #745 provided by Huub de Beer.
    (markt)
    + Fix: 69206: Ensure statements returned from Statement methods
    executeQuery(), getResultSet() and getGeneratedKeys() are correctly
    wrapped before being returned to the caller. Based on pull request
    [#742] provided by Michael Clarke.
  * Other
    + Update: Switch from DigiCert ONE to ssl.com eSigner for code signing.
    (markt)
    + Update: Update Byte Buddy to 1.15.10. (markt)
    + Update: Update CheckStyle to 10.20.0. (markt)
    + Add: Improvements to German translations. (remm)
    + Add: Improvements to French translations. (remm)
    + Add: Improvements to Japanese translations by tak7iji. (markt)
    + Add: Improvements to Chinese translations by Ch_jp. (markt)
    + Add: Exclude the tomcat-coyote-ffm.jar from JAR scanning by default.
    (markt)
    + Fix: Change the default log handler level to ALL so log messages are
    not dropped by default if a logger is configured to use trace (FINEST)
    level logging. (markt)
    + Update: Update Hamcrest to 3.0. (markt)
    + Update: Update EasyMock to 5.4.0. (markt)
    + Update: Update Byte Buddy to 1.15.0. (markt)
    + Update: Update CheckStyle to 10.18.0. (markt)
    + Update: Update the internal fork of Apache Commons BCEL to 6.10.0.
    (markt)
    + Add: Improvements to Spanish translations by Fernando. (markt)
    + Add: Improvements to French translations. (remm)
    + Add: Improvements to Japanese translations by tak7iji. (markt)
    + Fix: Fix packaging regression with missing osgi information following
    addition of the test-only build target. (remm)
    + Update: Update Tomcat Native to 1.3.1. (markt)
    + Update: Update Byte Buddy to 1.14.18. (markt)
    + Add: Improvements to French translations. (remm)
    + Add: Improvements to Japanese translations by tak7iji. (markt)
* Thu Oct  3 2024 Fridrich Strba <fstrba@suse.com>
- Adapt the scripts to run also with javapackages-tools >= 6.3
* Sun Sep 29 2024 Fridrich Strba <fstrba@suse.com>
- Fix build after removal of the default %%%%{java_home} define
* Mon Jul  8 2024 Fridrich Strba <fstrba@suse.com>
- Modified patch:
  * tomcat-9.0-osgi-build.patch
    + move the definition of bnd.classpath out of the setup-bnd task
    since it is one component in build.classpath
* Mon Jul  8 2024 Ricardo Mestre <ricardo.mestre@suse.com>
- Update to Tomcat 9.0.91
  * Fixed CVEs:
    + CVE-2024-34750: Improper handling of exceptional conditions
    (bsc#1227399)
  * Catalina
    + Fix: Allow JAASRealm to use the configuration source to load a configured
    configFile, for easier use with testing. (remm)
    + Fix: Add missing algorithm callback to the JAASCallbackHandler. (remm)
    + Fix: 69131: Expand the implementation of the filter value of the
    Authenticator attribute allowCorsPreflight, so that it applies to all
    requests that match the configured URL patterns for the CORS filter,
    rather than only applying if the CORS filter is mapped to /*. (markt)
    + Add: Add support for shallow copies when using WebDAV. (markt)
    + Code: Deprecate the WebdavFixFilter as it is no longer required. (markt)
    + Fix: 69066: Fix regression in SPNEGO authenticator when processing Base64.
    Submitted by Daniel Lyko. (remm)
    + Update: Update minimum recommended version of Tomcat Native to 1.3.0. Pull
    request #728 provided by Dimitrios Soumis. (markt)
    + Update: The system property org.apache.catalina.connector.RECYCLE_FACADES
    will now default to true if not specified, which will in turn set the
    default value for the discardFacades connector attribute, thus causing
    facade objects to be discarded by default. (remm)
    + Add: Add RealmBase.getPrincipal(GSSName, GSSCredential, GSSContext) for
    retrieving extended/additional information from an established GSS
    context. (michaelo)
    + Fix: Correct a regression in the fix for 68721 that caused some instances
    of LinkageError to be reported as ClassNotFoundException. (markt)
    + Fix: Ensure that static resources deployed via a JAR file remain
    accessible when the context is configured to use a bloom filter. Based on
    pull request #730 provided by bergander. (markt)
    + Add: Introduce reference counting so the AprLifecycleListener is more
    robust. This particularly targets more complex embedded configurations
    with multiple server instances with independent lifecycles where more than
    one server instance requires the AprLifecycleListener. (markt)
    + Update: Deprecate and remove sessionCounter (replaced by the addition of
    the active session count and the expired session count, as a reasonable
    approximation) and duplicates (which does not represent a possible event
    in current implementations) statistics from the session manager. (remm)
    + Fix: 68890 Align output encoding of JSPs in the Manager webapp with the
    XML declarations in those same files. (schultz)
    + Fix: Update Basic authentication to implement the requirements of RFC 7617
    including the changing of the trimCredentials setting which is now
    defaults to false. Note that the trimCredentials setting will be removed
    in Tomcat 11. (markt)
    + Add: Small performance optimization when logging cookies with no values.
    (schultz)
    + Fix: Correct error handling for asynchronous requests. If the application
    performs an dispatch during AsyncListener.onError() the dispatch is now
    performed rather than completing the request using the error page
    mechanism. (markt)
    + Fix: Fix WebDAV lock null (locks for non existing resources) thread safety
    and removal. (remm)
    + Fix: Add periodic checking for WebDAV locks expiration. (remm)
    + Fix: Extend Asn1Parser to parse UTF8Strings. (michaelo)
    + Update: Add highConcurrencyStatus attribute to the SemaphoreValve to
    optionally allow the valve to return an error status code to the client
    when a permit cannot be acquired from the semaphore. (remm)
    + Add: Add checking of the "age" of the running Tomcat instance since its
    build-date to the SecurityListener, and log a warning if the server is
    old. (schultz)
    + Fix: When using the AsyncContext, throw an IllegalStateException, rather
    than allowing an NullPointerException, if an attempt is made to use the
    AsyncContext after it has been recycled. (markt)
    + Fix: Change the thread-safety mechanism for protecting
    StandardServer.services from a simple synchronized lock to a
    ReentrantReadWriteLock to allow multiple readers to operate
    simultaneously. Based upon a suggestion by Markus Wolfe. (schultz)
    + Fix: Improve Service connectors, Container children and Service executors
    access sync using a ReentrantReadWriteLock. (remm)
    + Fix: Improve handling of integer overflow if an attempt is made to upload
    a file via the Servlet API and the file is larger than
    Integer.MAX_VALUE. (markt)
    + Fix: 68862: Handle possible response commit when processing read errors.
    (remm)
  * Jasper
    + Fix: Update the optimisation in jakarta.el.ImportHandler so it is aware of
    new classes added to the java.lang package in Java 23. (markt)
    + Fix: Ensure that an exception in toString() still results in an
    ELException when an object is coerced to a String using
    ExpressionFactory.coerceToType(). (markt)
    + Add: Add support for specifying Java 24 (with the value 24) as the
    compiler source and/or compiler target for JSP compilation. If used with
    an Eclipse JDT compiler version that does not support these values, a
    warning will be logged and the default will used. (markt)
    + Fix: 69135: When using include directives in a tag file packaged in a JAR
    file, ensure that context relative includes are processed correctly. (
    markt)
    + Fix: 69135: When using include directives in a tag file packaged in a JAR
    file, ensure that file relative includes are processed correctly. (markt)
    + Fix: 69135: When using include directives in a tag file packaged in a JAR
    file, ensure that file relative includes are are not permitted to access
    files outside of the /META_INF/tags/ directory nor outside of the JAR
    file. (markt)
    + Fix: 68546: Small additional optimisation for initial loading of Servlet
    code generated for JSPs. Based on a suggestion by Dan Armstrong. (markt)
    + Add: Add support for specifying Java 23 (with the value 23) as the
    compiler source and/or compiler target for JSP compilation. If used with
    an Eclipse JDT compiler version that does not support these values, a
    warning will be logged and the default will used. (markt)
    + Fix: Handle the case where the JSP engine forwards a request/response to a
    Servlet that uses an OutputStream rather than a Writer. This was
    triggering an IllegalStateException on code paths where there was a
    subsequent attempt to obtain a Writer. (markt)
    + Fix: Correctly handle the case where a tag library is packaged in a JAR
    file and the web application is deployed as a WAR file rather than an
    unpacked directory. (markt)
    + Fix: Prevent the web application's ClassLoader from being pinned by the
    JSP compiler if an application uses a custom XMLInputFactory. Based upon a
    suggestion from Simon Niederberger. (schultz)
  * Web applications
    + Fix: Fix status servlet detailed view of the connectors when using
    automatic port. (remm)
    + Add: Add the ability to set a sub-title for the Manager web application
    main page. This is intended to allow users with lots of instances to
    easily distinguish them. Based on pull request #724 by Simon Arame.
    (markt)
    + Fix: Examples: Improve performance of WebSocket chat application when
    multiple clients disconnect at the same time. (markt)
    + Update: Examples: Increase the number of previous messages displayed when
    using the WebSocket chat application. (markt)
    + Fix: Examples: Improve performance of WebSocket snake application when
    multiple clients disconnect at the same time. (markt)
  * Coyote
    + Fix: Improve the algorithm used to identify the IP address to use to
    unlock the acceptor thread when a Connector is listening on all local
    addresses. Interfaces that are configured for point to point connections
    or are not currently up are now skipped. (markt)
    + Fix: 69121: Ensure that the onComplete() event is triggered if
    AsyncListener.onError() dispatches to a target that throws an exception.
    (markt)
    + Fix: Following the trailer header field refactoring, -1 is no longer an
    allowed value for maxTrailerSize. Adjust documentation accordingly. (remm)
    + Fix: 69068: Ensure read timouts are triggered for asynchronous,
    non-blocking reads when using HTTP/2. (markt)
    + Update: 69133: Add task queue size configuration on the Connector element,
    similar to the Executor element, for consistency. (remm)
    + Fix: Make counting of active HTTP/2 streams per connection more robust.
    (markt)
    + Add: Add support for TLS 1.3 client initiated re-keying. (markt)
    + Fix: Align non-secure and secure writes with NIO and skip the write
    attempt when there are no bytes to be written. (markt)
    + Fix: Allow any positive value for socket.unlockTimeout. If a negative or
    zero value is configured, the default of 250ms will be used. (mark)
    + Fix: Reduce the time spent waiting for the connector to unlock. The
    previous default of 10s was noticeably too long for cases where the unlock
    has failed. The wait time is now 100ms plus twice socket.unlockTimeout.
    (markt)
    + Fix: Ensure that the onAllDataRead() event is triggered when the request
    body uses chunked encoding and is read using non-blocking IO. (markt)
    + Fix: 68934: Add debug logging in the latch object when exceeding
    maxConnections. (remm)
    + Fix: Refactor trailer field handling to use a MimeHeaders instance to
    store trailer fields. (markt)
    + Fix: Ensure that multiple instances of the same trailer field are handled
    correctly. (markt)
    + Fix: Fix non-blocking reads of chunked request bodies. (markt)
    + Fix: When an invalid HTTP response header was dropped, an off-by-one error
    meant that the first header in the response was also dropped. Fix based on
    pull request #710 by foremans. (markt)
    + Fix: Add threadsMaxIdleTime attribute to the endpoint, to allow
    configuring the amount of time before an internal executor will scale back
    to the configured minSpareThreads size. (remm)
  * WebSocket
    + Fix: 68884: Reduce the write timeout when writing WebSocket close messages
    for abnormal closes. The timeout defaults to 50 milliseconds and may be
    controlled using the
    org.apache.tomcat.websocket.ABNORMAL_SESSION_CLOSE_SEND_TIMEOUT property
    in the user properties collection associated with the WebSocket session.
    (markt)
  * Other
    + Update: Add test-only build target to allow running only the testsuite,
    supporting Java versions down to the minimum supported to run Tomcat.
    (rjung)
    + Update: Update UnboundID to 7.0.1. (markt)
    + Update: Update to SpotBugs 4.8.6. (markt)
    + Update: Remove cglib dependency as it is not required by the version of
    EasyMock used by the unit tests. (markt)
    + Update: Update EasyMock to 5.3.0. This adds a test dependency on
    Byte-Buddy 1.14.17. (markt)
    + Add: Improvements to Czech translations by Vladimír Chlup. (markt)
    + Add: Improvements to French translations. (remm)
    + Add: Improvements to Japanese translations by tak7iji. (markt)
    + Add: Improvements to Chinese translations by fangzheng. (markt)
    + Update: Revert Derby to 10.16.1.1 as that is the latest version of Derby
    that runs on Java 17. (markt)
    + Update: Update to Commons Daemon 1.4.0. (markt)
    + Update: Update to Objenesis 3.4. (markt)
    + Update: Update to Checkstyle 10.17.0. (markt)
    + Update: Update to SpotBugs 4.8.5. (markt)
    + Add: Improvements to French translations. (remm)
    + Add: Improvements to Japanese translations by tak7iji. (markt)
    + Update: Switch to using the Base64 encoder and decoder provided by the JRE
    rather than the version provided by Commons Codec. The internal fork of
    Commons Codec has been deprecated and will be removed in Tomcat 11.
    (markt)
    + Update: Update NSIS to 3.10. (mark0t)
    + Update: Update UnboundID to 7.0.0. (markt)
    + Update: Update Checkstyle to 10.16.0. (markt)
    + Update: Update JaCoCo to 0.8.12. (markt)
    + Update: Update SpotBugs to 4.8.4. (markt)
    + Update: Update the internal fork of Apache Commons BCEL to 6.9.0. (markt)
    + Update: Update the internal fork of Apache Commons DBCP to 2.12.0. (markt)
    + Add: Improvements to Japanese translations by tak7iji. (markt)
    + Update: Update Checkstyle to 10.14.1. (markt)
    + Update: Update the internal fork of Apache Commons BCEL to 6.8.2. (markt)
    + Update: Update the internal fork of Apache Commons Codec to 1.16.1.
    (markt)
    + Add: Improvements to French translations. (remm)
    + Add: Improvements to Japanese translations by tak7iji. (remm)
    + Add: Improvements to Chinese translations by leeyazhou. (remm)
- Modified patch:
  * tomcat-9.0-build-with-java-11.patch
    + rediff to changed context
* Fri Apr  5 2024 Ricardo Mestre <ricardo.mestre@suse.com>
- Update to Tomcat 9.0.87
  * Fixed CVEs:
    + CVE-2024-24549: Improved request header validation for HTTP/2 stream
    (bsc#1221386)
    + CVE-2024-23672: Ensure that WebSocket connection closure completes if
    the connection is closed when the server side has used the proprietary
    suspend/resume feature to suspend the connection (bsc#1221385)
  * Catalina
    + Fix:  Minor performance improvement for building filter chains. Based
    on ideas from #702 by Luke Miao. (remm)
    + Fix:  Align error handling for Writer and OutputStream. Ensure use of
    either once the response has been recycled triggers a
    NullPointerException provided that discardFacades is configured with
    the default value of true. (markt)
    + Fix:  68692: The standard thread pool implementations that are configured
    using the Executor element now implement ExecutorService for better
    support NIO2. (remm)
    + Fix:  68495: When restoring a saved POST request after a successful FORM
    authentication, ensure that neither the URI, the query string nor the
    protocol are corrupted when restoring the request body. (markt)
    + Fix:  68721: Workaround a possible cause of duplicate class definitions
    when using ClassFileTransformers and the transformation of a class also
    triggers the loading of the same class. (markt)
    + Fix:  The rewrite valve should not do a rewrite if the output is
    identical to the input. (remm)
    + Update:  Add a new valveSkip (or VS) rule flag to the rewrite valve to
    allow skipping over the next valve in the Catalina pipeline. (remm)
    + Fix:  Correct JPMS and OSGi meta-data for tomcat-enbed-core.jar by
    removing reference to org.apache.catalina.ssi package that is no longer
    included in the JAR. Based on pull request #684 by Jendrik Johannes.
    (markt)
    + Fix:  Fix ServiceBindingPropertySource so that trailing \r\n sequences
    are correctly removed from files containing property values when
    configured to do so. Bug identified by Coverity Scan. (markt)
    + Add:  Add improvements to the CSRF prevention filter including the
    ability to skip adding nonces for resource name and subtree URL patterns.
    (schultz)
    + Fix:  Review usage of debug logging and downgrade trace or data dumping
    operations from debug level to trace. (remm)
    + Fix:  68089: Further improve the performance of request attribute
    access for ApplicationHttpRequest and ApplicationRequest. (markt)
    + Fix:  68559: Allow asynchronous error handling to write to the
    response after an error during asynchronous processing. (markt)
  * Coyote
    + Fix:  Improve the HTTP/2 stream prioritisation process. If a stream
    uses all of the connection windows and still has content to write, it
    will now be added to the backlog immediately rather than waiting until
    the write  attempt for the remaining content. (markt)
    + Fix:  Make asynchronous error handling more robust. Ensure that once
    a connection is marked to be closed, further asynchronous processing
    cannot change that. (markt)
    + Fix:  Make asynchronous error handling more robust. Ensure that once
    the call to AsyncListener.onError() has returned to the container, only
    container threads can access the AsyncContext. This protects against
    various race conditions that woudl otherwise occur if application threads
    continued to access the AsyncContext.
    + Fix:  Review usage of debug logging and downgrade trace or data
    dumping operations from debug level to trace. In particular, most of the
    HTTP/2 debug logging has been changed to trace level. (remm)
    + Fix:  Add support for user provided SSLContext instances configured
    on SSLHostConfigCertificate instances. Based on pull request #673
    provided by Hakan Altındağ. (markt)
    + Fix:  Improve the Tomcat Native shutdown process to reduce the likelihood
    of a JVM crash during Tomcat shutdown. (markt)
    + Fix:  Partial fix for 68558: Cache the result of converting to String
    for request URI, HTTP header names and the request Content-Type value to
    improve performance by reducing repeated byte[] to String conversions.
    (markt)
    + Fix:  Improve error reporting to HTTP/2 clients for header processing
    errors by reporting problems at the end of the frame where the error was
    detected rather than at the end of the headers. (markt)
    + Fix:  Remove the remaining reference to a stream once the stream has
    been recycled. This makes the stream eligible for garbage collection
    earlier and thereby improves scalability. (markt)
  * Jasper
    + Add:  Add support for specifying Java 22 (with the value 22) as the
    compiler source and/or compiler target for JSP compilation. If used with
    an  Eclipse JDT compiler version that does not support these values, a
    warning will be logged and the default will used. (markt)
    + Fix:  68546: Generate optimal size and types for JSP imports maps, as
    suggested by John Engebretson. (remm)
    + Fix:  Review usage of debug logging and downgrade trace or data
    dumping operations from debug level to trace. (remm)
  * Cluster
    + Fix:  Avoid updating request count stats on async. (remm)
  * WebSocket
    + Fix:  Correct a regression in the fix for 66508 that could cause an
    UpgradeProcessor leak in some circumstances. (markt)
    + Fix:  Review usage of debug logging and downgrade trace or data dumping
    operations from debug level to trace. (remm)
    + Fix:  Ensure that WebSocket connection closure completes if the
    connection is closed when the server side has used the proprietary
    suspend/resume feature to suspend the connection. (markt)
  * Web applications
    + Add:  Add support for responses in JSON format from the examples
    application RequestHeaderExample. (schultz)
  * Other
    + Add:  Improvements to French translations. (remm)
    + Add:  Improvements to Japanese translations by tak7iji. (markt)
    + Update:  Update Checkstyle to 10.13.0. (markt)
    + Update:  Update JSign to 6.0. (markt)
    + Update:  Add strings for debug level messages. (remm)
    + Update:  Update Tomcat Native to 1.3.0. (markt)
    + Add:  Improvements to French translations. (remm)
    + Add:  Improvements to Japanese translations by tak7iji. (markt)
* Wed Mar  6 2024 Dan Čermák <dcermak@suse.com>
- Add missing Requires(post): util-linux to have runuser into post
* Mon Mar  4 2024 Fridrich Strba <fstrba@suse.com>
- Add %%%%systemd_ordering to packages with systemd unit files, so
  that the order is the right one if those packages find themselves
  in the same transaction with systemd
* Sat Feb 17 2024 Fridrich Strba <fstrba@suse.com>
- Link ecj.jar into the install instead of copying it
* Tue Feb  6 2024 Michele Bussolotto <michele.bussolotto@suse.com>
- rpm 4.19 requires dependencies on tomcat user and group (bsc#1219530)
* Fri Jan 26 2024 Michele Bussolotto <michele.bussolotto@suse.com>
- Fixed CVEs:
  * CVE-2024-22029: run xsltproc as tomcat group (bsc#1219208)
* Wed Jan 17 2024 Michele Bussolotto <michele.bussolotto@suse.com>
- Update to Tomcat 9.0.85
  * Fixed CVEs:
    + CVE-2023-46589: Apache Tomcat: HTTP request smuggling due to
    incorrect headers parsing (bsc#1217649)
  * Catalina
    + Update:  68378: Align extension to MIME type mappings in the
    global web.xml with those in httpd by adding
    application/vnd.geogebra.slides for ggs, text/javascript for mjs
    and audio/ogg for opus. (markt)
    + Fix:  Background processes should not be run concurrently with
    lifecycle operations of a container. (remm)
    + Fix:  Correct unintended escaping of XML in some WebDAV
    responses. The XML list of support locks when provided in
    response to a PROPFIND request was incorrectly XML escaped.
    (markt)
    + Fix:  68227: Ensure that AsyncListener.onComplete() is called
    if AsyncListener.onError() calls AsyncContext.dispatch().
    (markt)
    + Fix:  68228: Use a 408 status code if a read timeout occurs
    during HTTP request processing. Includes a test case based on
    code provided by adwsingh. (markt)
    + Fix:  67667: TLSCertificateReloadListener prints unreadable
    rendering of X509Certificate#getNotAfter(). (michaelo)
    + Update:  The status servlet included in the manager webapp
    can now output statistics as JSON, using the JSON=true URL
    parameter. (remm)
    + Update:  Optionally allow ServiceBindingPropertySource to
    trim a trailing newline from a file containing a
    property-value. (schultz)
    + Fix:  67793: Ensure the original session timeout is restored
    after FORM authentication if the user refreshes a page during
    the FORM authentication process. Based on a suggestion by
    Mircea Butmalai. (markt)
    + Update:  67926: PEMFile prints unidentifiable string
    representation of ASN.1 OIDs. (michaelo)
    + Fix:  66875: Ensure that setting the request attribute
    jakarta.servlet.error.exception is not sufficient to trigger
    error handling for the current request and response. (markt)
    + Fix:  68054: Avoid some file canonicalization calls
    introduced by the fix for 65433. (remm)
    + Fix:  68089: Improve performance of request attribute access
    for ApplicationHttpRequest and ApplicationRequest. (markt)
    + Fix:  Use a 400 status code to report an error due to a bad
    request (e.g. an invalid trailer header) rather than a 500
    status code. (markt)
    + Fix:  Ensure that an IOException during the reading of the
    request triggers always error handling, regardless of whether
    the application swallows the exception. (markt)
  * Coyote
    + Fix:  Refactor the VirtualThreadExecutor so that it can be
    used by the NIO2 connector which was using platform threads
    even when configured to use virtual threads. (markt)
    + Fix:  Correct a regression in the fix for 67675 that broke
    TLS key file parsing for PKCS#8 format keys that do not specify
    an explicit pseudo-random function and rely on the default.
    This typically affects keys generated by OpenSSL 1.0.2.
    (markt)
    + Fix:  Allow multiple operations with the same name on
    introspected mbeans, fixing a regression caused by the
    introduction of a second addSslHostConfig method. (remm)
    + Fix:  Relax the check that the HTTP Host header is consistent
    with the host used in the request line, if any, to make the
    check case insensitive since host names are case insensitive.
    (markt)
    + Add:  68348: Add support for the partitioned attribute for
    cookies. (markt)
    + Add:  66670: Add SSLHostConfig#certificateKeyPasswordFile and
    SSLHostConfig#certificateKeystorePasswordFile. (michaelo)
    + Add:  When calling
    SSLHostConfigCertificate.setCertificateKeystore(ks),
    automatically call setCertificateKeystoreType(ks.getType()).
    (markt)
    + Fix:  67628: Clarify how the ciphers attribute of the
    SSLHostConfig is used. (markt)
    + Fix:  67666: Ensure TLS connectors using PEM files either
    work with the TLSCertificateReloadListener or, in the rare case
    that they do not, log a warning on Connector start. (markt)
    + Fix:  67675: Support a wider range of KDF and ciphers for PEM
    files than the combinations supported by the JVM by default.
    Specifically, support the OpenSSL default of HmacSHA256 and
    DES-EDE3-CBC. (markt)
    + Fix:  67927: Reloading TLS configuration can cause the
    Connector to refuse new connections or the JVM to crash.
    (markt)
    + Fix:  67934: If both Tomcat Native 1.2.x and 2.0.x are
    available, prefer 1.2.x since it supports the APR/Native
    connector whereas 2.0.x does not. (markt)
    + Fix:  67938: Correct handling of large TLS client hello
    messages that were causing the TLS handshake to fail. (markt)
    + Fix:  68026: Convert selected MessageByte values to String
    when first accessed to speed up subsequent accesses and reduce
    garbage collection. (markt)
  * Jasper
    + Code:  68119: Refactor the CompositeELResolver to improve
    performance during type conversion operations. (markt)
    + Fix:  68068: Performance improvement for EL. Based on a
    suggestion by John Engebretson. (markt)
  * Web Applications
    + Fix:  68035: Additional fix to the Manager application to
    enable the deployment of a web application located in a Host's
    appBase where the web application is specified by a bare (no
    path) WAR or directory name as shown in the documentation.
    (markt)
    + Fix:  Examples. Improve the error handling so snakes
    associated with a user that drops from the network are removed
    from the game. (markt)
    + Fix:  68035: Correct a regression in the fix for 56248 that
    prevented deployment via the Manager of a WAR or directory that
    was already present in the appBase or a context file that was
    already present in the xmlBase. (markt)
  * Other
    + Update:  Update Checkstyle to 10.12.7. (markt)
    + Update:  Update SpotBugs to 4.8.3. (markt)
    + Add:  Improvements to French translations. (remm)
    + Add:  Improvements to Japanese translations by tak7iji.
    (markt)
    + Update:  Update UnboundID to 6.0.11. (markt)
    + Update:  Update Checkstyle to 10.12.5. (markt)
    + Update:  Update SpotBugs to 4.8.2. (markt)
    + Update:  Update Derby to 10.17.1. (markt)
    + Add:  Improvements to French translations. (remm)
    + Add:  Improvements to Japanese translations by tak7iji.
    (markt)
    + Add:  Improvements to Brazilian Portuguese translations by
    John William Vicente. (markt)
    + Add:  Improvements to Russian translations by usmazat and
    remm. (markt)
    + Add:  67538: Make use of Ant's <javaversion /> task to enfore
    the mininum Java build version. (michaelo)
    + Update:  Update Checkstyle to 10.12.4. (markt)
    + Update:  Update JaCoCo to 0.8.11. (markt)
    + Update:  Update SpotBugs to 4.8.0. (markt)
    + Update:  Update BND to 7.0.0. (markt)
    + Update:  The minimum Java version required to build Tomcat
    has been raised to Java 17. (markt)
- Added patches:
  * tomcat-9.0-build-with-java-11.patch
* Wed Jan 17 2024 Michele Bussolotto <michele.bussolotto@suse.com>
- change server.xml during %%post instead of %%posttrans
* Fri Jan 12 2024 Michele Bussolotto <michele.bussolotto@suse.com>
- Fix server.xml permission (bsc#1217768, bsc#1217402)
- remove serverxmltool and use xsltproc
* Thu Nov 23 2023 Ricardo Mestre <ricardo.mestre@suse.com>
- replace prep setup and patches macro with autosetup
* Fri Oct 13 2023 Fridrich Strba <fstrba@suse.com>
- Update to Tomcat 9.0.82
  * Fixed CVEs:
    + CVE-2023-45648: Improve trailer header parsing (bsc#1216118)
    + CVE-2023-42794: FileUpload: remove tmp files to avoid DoS
    on Windows (bsc#1216120)
    + CVE-2023-42795: Improve handling of failures during recycle()
    methods (bsc#1216119)
  * Catalina
    + Add: 65770: Provide a lifecycle listener that will
    automatically reload TLS configurations a set time before the
    certificate is due to expire. This is intended to be used with
    third-party tools that regularly renew TLS certificates.
    + Fix: Fix handling of an error reading a context descriptor on
    deployment.
    + Fix: Fix rewrite rule qsd (query string discard) being ignored
    if qsa was also use, while it should instead take precedence.
    + Fix: 67472: Send fewer CORS-related headers when CORS is not
    actually being engaged.
    + Add: Improve handling of failures within recycle() methods.
  * Coyote
    + Fix: 67670: Fix regression with HTTP compression after code
    refactoring.
    + Fix: 67198: Ensure that the AJP connector attribute
    tomcatAuthorization takes precedence over the
    tomcatAuthentication attribute when processing an auth_type
    attribute received from a proxy server.
    + Fix: 67235: Fix a NullPointerException when an AsyncListener
    handles an error with a dispatch rather than a complete.
    + Fix: When an error occurs during asynchronous processing,
    ensure that the error handling process is only triggered once
    per asynchronous cycle.
    + Fix: Fix logic issue trying to match no argument method in
    IntropectionUtil.
    + Fix: Improve thread safety around readNotify and writeNotify
    in the NIO2 endpoint.
    + Fix: Avoid rare thread safety issue accessing message digest
    map.
    + Fix: Improve statistics collection for upgraded connections
    under load.
    + Fix: Align validation of HTTP trailer fields with standard
    fields.
    + Fix: Improvements to HTTP/2 overhead protection (bsc#1216182,
    CVE-2023-44487)
  * jdbc-pool
    + Fix: 67664: Correct a regression in the clean-up of
    unnecessary use of fully qualified class names in 9.0.81
    that broke the jdbc-pool.
  * Jasper
    + Fix: 67080: Improve performance of EL expressions in JSPs that
    use implicit objects
* Thu Sep 21 2023 Fridrich Strba <fstrba@suse.com>
- Update to Tomcat 9.0.80
  * Catalina
    + Add RateLimitFilter which can be used to mitigate DoS and
    Brute Force attacks
    + Move the management of the utility executor from the
    init()/destroy() methods of components to the start()/stop()
    methods.
    + Add org.apache.catalina.core.StandardVirtualThreadExecutor,
    a virtual thread based executor that may be used with one or
    more Connectors to process requests received by those
    Connectors using virtual threads. This Executor requires a
    minimum Java version of Java 21.
    + 66513: Add a per session Semaphore to the PersistentValve that
    ensures that, within a single Tomcat instance, there is no
    more than one concurrent request per session. Also expand the
    debug logging to include whether a request bypasses the Valve
    and the reason if a request fails to obtain the per session
    Semaphore.
    + 66609: Ensure that the default servlet correctly escapes file
    names in directory listings when using XML output.
    + 66618: Add a numeric last modified field to the XML directory
    listings produced by the default servlet to enable sorting in
    the XSLT.
    + 66621: Attempts to lock a collection with WebDAV may
    incorrectly fail if a child collection has an expired lock.
    + 66622: Deprecate the xssProtectionEnabled setting from the
    HttpHeaderSecurityFilter and change the default value to false
    as support for the associated HTTP header has been removed
    from all major browsers.
    + 59232: Add org.apache.catalina.core.ContextNamingInfoListener,
    a listener which creates context naming information
    environment entries.
    + 66665: Add
    org.apache.catalina.core.PropertiesRoleMappingListener, a
    listener which populates the context's role mapping from a
    properties file.
    + Fix an edge case where intra-web application symlinks would be
    followed if the web applications were deliberately crafted to
    allow it even when allowLinking was set to false.
    + Add utility config file resource lookup on Context to allow
    looking up resources from the webapp (prefixed with webapp:)
    and make the resource lookup API more visible.
    + Fix potential database connection leaks in
    DataSourceUserDatabase identified by Coverity Scan.
    + Make parsing of ExtendedAccessLogValve patterns more robust.
    + Fix failure trying to persist configuration for an internal
    credential handler.
    + 66680: When serializing a session during the session
    presistence process, do not log a warning that null Principals
    are not serializable.
    + Catch NamingException in JNDIRealm#getPrincipal. It is used in
    Java up to 17 to signal closed connections.
    + 66822: Use the same naming format in log messages for
    Connector instances as the associated ProtocolHandler instance.
    + The parts count should also lower the actual maxParameterCount
    used for parsing parameters if parts are parsed first.
    + If an application or library sets both a non-500 error code
    and the javax.servlet.error.exception request attribute, use
    the provided error code during error page processing rather
    than assuming an error code of 500.
    + Update code comments and Tomcat output to use MiB for
    1024 * 1024 bytes and KiB for 1024 bytes rather than
    MB and kB.
    + Avoid protocol relative redirects in FORM authentication
    (CVE-2023-41080, bsc#1214666).
  * Coyote
    + Update the HTTP/2 implementation to use the prioritization
    scheme defined in RFC 9218 rather than the one defined in
    RFC 7540.
    + 66602: not sending WINDOW_UPDATE when dataLength is ZERO on
    call SwallowedDataFramePayload.
    + 66627: Restore the documented behaviour of
    MessageBytes.getType() that it returns the type of the
    original content rather than reflecting the most recent
    conversion.
    + 66635: Correct certificate logging on start-up so it
    differentiates between keystore based keys/certificates and
    PEM file based keys/certificates and logs the relevant
    information for each.
    + Refactor blocking reads and writes for the NIO connector to
    remove code paths that could allow a notification from the
    Poller to be missed resuting in a timeout rather than the
    expected read or write.
    + Refactor waiting for an HTTP/2 stream or connection window
    update to handle spurious wake-ups during the wait.
    + Correct a regression introduced in 9.0.78 and use the correct
    constant when constructing the default value for the
    certificateKeystoreFile attribute of an
    SSLHostConfigCertificate instance.
    + Refactor HTTP/2 implementation to reduce pinning when using
    virtual threads.
    + Pass through ciphers referring to an OpenSSL profile, such as
    PROFILE=SYSTEM instead of producing an error trying to parse
    it.
    + 66841: Ensure that AsyncListener.onError() is called after an
    error during asynchronous processing with HTTP/2.
    + 66842: When using asynchronous I/O (the default for NIO and
    NIO2), include DATA frames when calculating the HTTP/2
    overhead count to ensure that connections are not prematurely
    terminated.
    + Correct a race condition that could cause spurious RST
    messages to be sent after the response had been written to an
    HTTP/2 stream.
  * WebSocket
    + 66548: Expand the validation of the value of the
    Sec-Websocket-Key header in the HTTP upgrade request that
    initiates a WebSocket connection. The value is not decoded but
    it is checked for the correct length and that only valid
    characters from the base64 alphabet are used.
    + Improve handling of error conditions for the WebSocket server,
    particularly during Tomcat shutdown.
    + Correct a regression in the fix for 66574 that meant the
    WebSocket session could return false for onOpen() before the
    onClose() event had been completed.
    + 66681: Fix a NullPointerException when flushing batched
    messages with compression enabled using permessage-deflate.
  * Web applications
    + Documentation. Expand the security guidance to cover the
    embedded use case and add notes on the uses made of the
    java.io.tmpdir system property.
    + 66662: Documentation. Fix a typo in the name of the algorithms
    attribute in the configuration section for the Digest
    authentication value.
    + Documentation. Update documentation to use MiB for
    1024 * 1024 bytes and KiB for 1024 bytes rather than
    MB and kB.
  * jdbc-pool
    + Fix the releaseIdleCounter does not increment when testAllIdle
    releases them.
    + Fix the ConnectionState state will be inconsistent with actual
    state on the connection when an exception occurs while
    writing.
  * Other
    + Update to Commons Daemon 1.3.4.
    + Improvements to French translations.
    + Update Checkstyle to 10.12.0.
    + Update the packaged version of the Apache Tomcat Native
    Library to 1.2.37 to pick up the Windows binaries built with
    with OpenSSL 1.1.1u.
    + Include the Windows specific binary distributions in the files
    uploaded to Maven Central.
    + Improvements to French translations.
    + Improvements to Japanese translations.
    + Update UnboundID to 6.0.9.
    + Update Checkstyle to 10.12.1.
    + Update BND to 6.4.1.
    + Update JSign to 5.0.
    + Correct properties for JSign dependency.
    + Align documentation for maxParameterCount to match hard-coded
    defaults.
    + Update NSIS to 3.0.9.
    + Update Checkstyle to 10.12.2.
    + Improvements to French translations.
    + Improvements to Japanese translations.
    + 66829: Fix quoting so users can use the _RUNJAVA environment
    variable as intended on Windows when the path to the Java
    executable contains spaces.
    + Update Tomcat Native to 1.2.38 to pick up Windows binaries
    built with OpenSSL 1.1.1v.
    + Improvements to Chinese translations.
    + Improvements to French translations.
    + Improvements to Japanese translations
- Removed patch:
  * tomcat-9.0.75-CVE-2023-41080.patch
    + integrated in this version
* Thu Sep 21 2023 Michele Bussolotto <michele.bussolotto@suse.com>
- Fixed CVEs:
  * CVE-2023-41080: Avoid protocol relative redirects in FORM authentication. (bsc#1214666)
- Added patches:
  * tomcat-9.0.75-CVE-2023-41080.patch
* Mon Sep 18 2023 Fridrich Strba <fstrba@suse.com>
- Modified patch:
  * tomcat-9.0-osgi-build.patch
    + make it more robust to change in number of artifacts in bnd
    + do not enumerate jars, just take all jars from the aqute-bnd
    directory into the classpath
* Tue Sep 12 2023 Fridrich Strba <fstrba@suse.com>
- Require(pre) shadow because groupadd is needed early
* Tue May 23 2023 Fridrich Strba <fstrba@suse.com>
- Update to Tomcat 9.0.75.
  * See changelog at
    https://tomcat.apache.org/tomcat-9.0-doc/changelog.html#Tomcat_9.0.75_(markt)
  * Fixes:
    + bsc#1211608, CVE-2023-28709
    + bsc#1208513, CVE-2023-24998 (previous incomplete fix)
- Remove patches:
  * tomcat-9.0-CVE-2021-30640.patch
  * tomcat-9.0-CVE-2021-33037.patch
  * tomcat-9.0-CVE-2021-41079.patch
  * tomcat-9.0-CVE-2022-23181.patch
  * tomcat-9.0-NPE-JNDIRealm.patch
  * tomcat-9.0-hardening_getResources.patch
  * tomcat-9.0.43-CVE-2021-43980.patch
  * tomcat-9.0.43-CVE-2022-42252.patch
  * tomcat-9.0.43-CVE-2022-45143.patch
  * tomcat-9.0.43-CVE-2023-24998.patch
  * tomcat-9.0.43-CVE-2023-28708.patch
    + integrated in this version
  * tomcat-9.0.43-java8compat.patch
    + problem with Java 8 compatibility solved in this version
- Modified patch:
  * tomcat-9.0.31-secretRequired-default.patch
  - > tomcat-9.0.75-secretRequired-default.patch
    + rediffed to changed context
  * tomcat-9.0-javadoc.patch
    + drop integrated hunks
  * tomcat-9.0-osgi-build.patch
    + fix to work with current version
- Added patch:
  * tomcat-9.0-jdt.patch
    + fix build against our ecj
* Fri Apr  7 2023 Michele Bussolotto <michele.bussolotto@suse.com>
- Fixed CVEs:
  * CVE-2022-45143: JsonErrorReportValve: add escape for type, message or description (bsc#1206840)
- Added patches:
  * tomcat-9.0.43-CVE-2022-45143.patch
* Thu Mar 23 2023 Michele Bussolotto <michele.bussolotto@suse.com>
- Fixed CVEs:
  * CVE-2023-28708: tomcat: not including the secure attribute
    causes information disclosure (bsc#1209622)
- Added patches:
  * tomcat-9.0.43-CVE-2023-28708.patch
* Tue Feb 28 2023 Michele Bussolotto <michele.bussolotto@suse.com>
- Fixed CVEs:
  * CVE-2023-24998: tomcat,tomcat6: FileUpload DoS with excessive parts (bsc#1208513)
- Added patches:
  * tomcat-9.0.43-CVE-2023-24998.patch
* Fri Dec 23 2022 Michele Bussolotto <michele.bussolotto@suse.com>
- set logrotate for localhost.log, manager.log, host-manager.log and localhost_access_log.txt
- use logrotate for catalina.out
  * update tomcat-serverxml-tool and spec to configure server.xml
- Added patch:
  * tomcat-9.0-logrotate_everything.patch
  * tomcat-serverxml-tool.tar.gz
- Removed:
  * tomcat-serverxml-tool-1.0.tar.gz
* Tue Nov 29 2022 Michele Bussolotto <michele.bussolotto@suse.com>
- Use catalina.out for logging (bsc#1205647)
- Added patches:
  * tomcat-9.0-fix_catalina.patch
* Mon Nov 21 2022 Michele Bussolotto <michele.bussolotto@suse.com>
- Fixed CVEs:
  * CVE-2022-42252: reject invalid content-length requests. (bsc#1204918)
- Added patches:
  * tomcat-9.0.43-CVE-2022-42252.patch
* Thu Oct 20 2022 Michele Bussolotto <michele.bussolotto@suse.com>
- Fixed CVEs:
  * CVE-2021-43980: Improve the recycling of Processor objects to make it more robust. (bsc#1203868)
- Added patches:
  * tomcat-9.0.43-CVE-2021-43980.patch
* Wed Jul 13 2022 Fridrich Strba <fstrba@suse.com>
- Do not hardcode /usr/libexec but use %%%%_libexecdir during the
  build
  * Fixes for platforms, where /usr/libexec and %%%%_libexecdir are
    different
* Thu Jul  7 2022 Fridrich Strba <fstrba@suse.com>
- Fix bsc#1201081 by building with release=8 all files that can be
  built this way. The one file remaining, build it with source=8 and
  target=8
- Modified patch:
  * tomcat-9.0.43-java8compat.patch
    + Do not cast ByteBuffer to Buffer to call the Java 8 compatible
    methods. Build with release=8 instead
* Thu Apr  7 2022 Michele Bussolotto <michele.bussolotto@suse.com>
- Security hardening. Deprecate getResources() and always return null. (bsc#1198136)
- Added patch: tomcat-9.0-hardening_getResources.patch
* Wed Feb 23 2022 Fridrich Strba <fstrba@suse.com>
- Remove dependency on log4j/reload4j completely (bsc#1196137)
* Tue Feb 22 2022 Fridrich Strba <fstrba@suse.com>
- Do not build against the log4j12 packages, use the new reload4j
* Fri Jan 28 2022 Michele Bussolotto <michele.bussolotto@suse.com>
- Fixed CVEs:
  * CVE-2022-23181: Make calculation of session storage location more robust (bsc#1195255)
- Added patches:
  * tomcat-9.0-CVE-2022-23181.patch
* Mon Jan 10 2022 olaf@aepfle.de
- remove instance units from post scripts, they can not be reloaded
* Fri Dec 10 2021 Michele Bussolotto <michele.bussolotto@suse.com>
- Fix NPE in JNDIRealm, when userRoleAttribute is not set (bsc#1193569)
- Added patch:
  * tomcat-9.0-NPE-JNDIRealm.patch
* Wed Nov 10 2021 Fridrich Strba <fstrba@suse.com>
- Modified patch:
  * tomcat-9.0-osgi-build.patch
    + account for biz.aQute.bnd.ant artifact in aqute-bnd >= 5.2.0
* Fri Oct 29 2021 Michele Bussolotto <michele.bussolotto@suse.com>
- Fixed CVEs:
  * CVE-2021-30640: Escape parameters in JNDI Realm queries (bsc#1188279)
  * CVE-2021-33037: Process T-E header from both HTTP 1.0 and HTTP 1.1. clients (bsc#1188278)
- Added patches:
  * tomcat-9.0-CVE-2021-30640.patch
  * tomcat-9.0-CVE-2021-33037.patch
* Thu Oct 28 2021 Michele Bussolotto <michele.bussolotto@suse.com>
- Fixed CVEs:
  * CVE-2021-41079: Validate incoming TLS packet (bsc#1190558)
- Added patches:
  * tomcat-9.0-CVE-2021-41079.patch
* Mon Oct 18 2021 Marcel Witte <wittemar@googlemail.com>
- Update to Tomcat 9.0.43. See changelog at
  https://tomcat.apache.org/tomcat-9.0-doc/changelog.html#Tomcat_9.0.43_(markt)
- Removed Patches because fixed upstream now:
  * tomcat-9.0-CVE-2021-25122.patch
  * tomcat-9.0-CVE-2021-25329.patch
- Rebased patch:
  tomcat-9.0.39-java8compat.patch -> tomcat-9.0.43-java8compat.patch
* Mon Oct 18 2021 Marcel Witte <wittemar@googlemail.com>
- Update to Tomcat 9.0.41. See changelog at
  https://tomcat.apache.org/tomcat-9.0-doc/changelog.html#Tomcat_9.0.41_(markt)
* Mon Oct 18 2021 Marcel Witte <wittemar@googlemail.com>
- Update to Tomcat 9.0.40. See changelog at
  https://tomcat.apache.org/tomcat-9.0-doc/changelog.html#Tomcat_9.0.40_(markt)
- Removed Patches because fixed upstream now:
  * tomcat-9.0-CVE-2020-17527.patch
  * tomcat-9.0-CVE-2021-24122.patch
* Mon Mar 22 2021 Abid Mehmood <amehmood@suse.com>
- Fixed CVEs:
  * CVE-2021-25122: Apache Tomcat h2c request mix-up (bsc#1182912)
  * CVE-2021-25329: Complete fix for CVE-2020-9484 (bsc#1182909)
- Added patches:
  * tomcat-9.0-CVE-2021-25122.patch
  * tomcat-9.0-CVE-2021-25329.patch
* Wed Mar 17 2021 Abid Mehmood <amehmood@suse.com>
- Log if file access is blocked due to symlinks: CVE-2021-24122 (bsc#1180947)
- Added patch:
  * tomcat-9.0-CVE-2021-24122.patch
* Mon Mar 15 2021 Marcel Witte <wittemar@googlemail.com>
- Update to Tomcat 9.0.39. See changelog at
  https://tomcat.apache.org/tomcat-9.0-doc/changelog.html#Tomcat_9.0.39_(markt)
- Rebased patches:
  * tomcat-9.0.38-java8compat.patch -> tomcat-9.0.39-java8compat.patch
* Mon Mar 15 2021 Marcel Witte <wittemar@googlemail.com>
- Update to Tomcat 9.0.38. See changelog at
  https://tomcat.apache.org/tomcat-9.0-doc/changelog.html#Tomcat_9.0.38_(markt)
- Rebased patches:
  * tomcat-9.0.37-java8compat.patch -> tomcat-9.0.38-java8compat.patch
- Removed tomcat-9.0-CVE-2020-13943.patch because that fix is upstream now
* Mon Feb 22 2021 Marcel Witte <wittemar@googlemail.com>
- Update to Tomcat 9.0.37. See changelog at
  https://tomcat.apache.org/tomcat-9.0-doc/changelog.html#Tomcat_9.0.37_(markt)
- Fixed CVEs:
  * CVE-2020-13934 (bsc#1174121)
  * CVE-2020-13935 (bsc#1174117)
- Rebased patches:
  * tomcat-9.0-osgi-build.patch
  * tomcat-9.0.31-java8compat.patch -> tomcat-9.0.37-java8compat.patch
* Wed Dec 16 2020 Abid Mehmood <amehmood@suse.com>
- Fix HTTP/2 request header mix-up: CVE-2020-17527 (bsc#1179602)
- Added patch:
  * tomcat-9.0-CVE-2020-17527.patch
* Tue Nov  3 2020 Matei Albu <malbu@suse.com>
- Add source url for tomcat-serverxml-tool
- Fix typo in tomcat-webapps %%postun that caused /examples
  context to remain in server.xml when package was removed
- Remove tomcat-9.0.init and /usr/lib/tmpfiles.d/tomcat.conf from
  package. They're not used anymore becuse of systemd (bsc#1178396)
* Fri Oct 30 2020 Matei Albu <malbu@suse.com>
- Fix tomcat-servlet-4_0-api package alternatives to use
  /usr/share/java/servlet.jar instead of /usr/share/java/tomcat-servlet.jar.
  Keep /usr/share/java/tomcat-servlet.jar symlink for compatibility.
  (bsc#1092163)
- Change default file ownership in tomcat-webapps from
  tomcat:tomcat to root:tomcat
* Tue Oct 13 2020 Matei Albu <malbu@suse.com>
- Fix CVE-2020-13943 (bsc#1177582)
- Added patch:
  * tomcat-9.0-CVE-2020-13943.patch
- Change /usr/lib/tomcat to /usr/libexec/tomcat in startup
  scripts (bsc#1177601)
* Tue Oct 13 2020 Jan Engelhardt <jengelh@inai.de>
- Replace old specfile constructs. Remove support for SUSE 11.x.
- Drop %%systemd_requires, which is considered a no-op.
- Trim redundant license mention from description.
- Make documentation noarch.
- Do not suppress errors from useradd.
* Wed Aug 26 2020 Fridrich Strba <fstrba@suse.com>
- Avoid hardcoding /usr/lib as libexecdir
* Wed Jul 29 2020 Matei Albu <malbu@suse.com>
- Don't give write permissions for the tomcat group on files and
  directories where it's not needed (bsc#1172562)
- Change tomcat.pid location from /var/run to /run (bsc#1173103)
- Use the /sbin/nologin shell when creating the tomcat user
- Use %%tmpfiles_create macro in %%post instead of calling
  systemd-tmpfiles directly
* Fri Jun 26 2020 Fridrich Strba <fstrba@suse.com>
- Update to Tomcat 9.0.36. See changelog at
  https://tomcat.apache.org/tomcat-9.0-doc/changelog.html#Tomcat_9.0.36_(markt)
- Fixed CVEs:
  CVE-2020-11996 (bsc#1173389)
* Tue May 26 2020 Matei Albu <malbu@suse.com>
- Update to Tomcat 9.0.35. See changelog at
  https://tomcat.apache.org/tomcat-9.0-doc/changelog.html#Tomcat_9.0.35_(markt)
- Fixed CVEs:
  - CVE-2020-9484 (bsc#1171928)
- Rebased patches:
  * tomcat-9.0-javadoc.patch
  * tomcat-9.0-osgi-build.patch
  * tomcat-9.0.31-java8compat.patch
* Fri Apr 10 2020 Javier Llorente <javier@opensuse.org>
- Update to Tomcat 9.0.34. See changelog at
  https://tomcat.apache.org/tomcat-9.0-doc/changelog.html#Tomcat_9.0.34_(markt)
- Notable changes:
  * Add support for default values when using ${...} property
    replacement in configuration files. Based on a pull request
    provided by Bernd Bohmann.
  * When configuring an HTTP Connector, warn if the encoding
    specified for URIEncoding is not a superset of US-ASCII as
    required by RFC 7230.
  * Replace the system property
    org.apache.tomcat.util.buf.UDecoder.ALLOW_ENCODED_SLASH with
    the Connector attribute encodedSolidusHandling that adds an
    additional option to pass the %%2f sequence through to the
    application without decoding it in addition to rejecting such
    sequences and decoding such sequences.
* Mon Mar 30 2020 Matei Albu <malbu@suse.com>
- Update to Tomcat 9.0.33. See changelog at
  http://tomcat.apache.org/tomcat-9.0-doc/changelog.html#Tomcat_9.0.33_(markt)
- Notable fix: corrected a regression in the improvements to HTTP
  header parsing (bsc#1167438)
- Rebased patches:
  * tomcat-9.0-javadoc.patch
  * tomcat-9.0-osgi-build.patch
  * tomcat-9.0.31-java8compat.patch
* Fri Feb 28 2020 Matei Albu <malbu@suse.com>
- Change default value of AJP connector secretRequired to false
- Added patch:
  * tomcat-9.0.31-secretRequired-default.patch
* Tue Feb 25 2020 Fridrich Strba <fstrba@suse.com>
- Update to Tomcat 9.0.31. See changelog at
  http://tomcat.apache.org/tomcat-9.0-doc/changelog.html#Tomcat_9.0.30_(markt)
- Fixed CVEs:
  * CVE-2019-17569 (bsc#1164825)
  * CVE-2020-1935 (bsc#1164860)
  * CVE-2020-1938 (bsc#1164692)
- Modified patch
  * tomcat-9.0.30-java8compat.patch
  - > tomcat-9.0.31-java8compat.patch
    + Adapt to changed context
* Wed Jan 29 2020 Matei Albu <malbu@suse.com>
- Modified patch:
  * tomcat-9.0.30-java8compat.patch
    + add missing casts (bsc#1162081)
* Mon Jan 20 2020 Fridrich Strba <fstrba@suse.com>
- Change back the build to build with any Java >= 1.8
- Added patch:
  * tomcat-9.0.30-java8compat.patch
    + Cast java.nio.ByteBuffer and java.nio.CharBuffer to
    java.nio.Buffer in order to avoid calling Java 9+ APIs
    (functions with co-variant return types)
- Renamed patch:
  * tomcat-9.0-disable-osgi-build.patch
  - > tomcat-9.0-osgi-build.patch
    + Do not disable, but fix OSGi build since we have now
    aqute-bnd
* Fri Jan 17 2020 Matei Albu <malbu@suse.com>
- Change build to always use Java 1.8 (bsc#1161025).
* Fri Dec 27 2019 Matei Albu <malbu@suse.com>
- Update to Tomcat 9.0.30. See changelog at
  http://tomcat.apache.org/tomcat-9.0-doc/changelog.html#Tomcat_9.0.30_(markt)
- Fixed CVEs:
  - CVE-2019-0221 (bsc#1136085)
  - CVE-2019-10072 (bsc#1139924)
  - CVE-2019-12418 (bsc#1159723)
  - CVE-2019-17563 (bsc#1159729)
- Removed patch:
  * tomcat-9.0-JDTCompiler-java.patch
    + It was not applied
* Mon Nov 18 2019 Fridrich Strba <fstrba@suse.com>
- Update to Tomcat 9.0.27. See changelog at
  http://tomcat.apache.org/tomcat-9.0-doc/changelog.html#Tomcat_9.0.27_(markt)
- Uset aqute-bnd to generate OSGi manifest, since we have that
  package now in openSUSE:Factory
- Removed patch:
  * tomcat-9.0-disable-osgi-build.patch
    + not needed
* Fri Nov 15 2019 Fridrich Strba <fstrba@suse.com>
- Add maven pom files for tomcat-jni and tomcat-jaspic-api
* Fri Oct  4 2019 Fridrich Strba <fstrba@suse.com>
- Distribute the pom file also for tomcat-util-scan artifact
* Tue Oct  1 2019 Fridrich Strba <fstrba@suse.com>
- Build against compatibility log4j12 package
* Wed Sep 25 2019 Fridrich Strba <fstrba@suse.com>
- Adapt to the new ecj directory layout
* Wed Jun 12 2019 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(systemd) instead of systemd: allow OBS to
  shortcut the build queues by allowing usage of systemd-mini
* Mon May 20 2019 Matei <malbu@suse.com>
- Update to Tomcat 9.0.20. See changelog at
  http://tomcat.apache.org/tomcat-9.0-doc/changelog.html#Tomcat_9.0.20_(markt)
- increase maximum number of threads and open files for tomcat (bsc#1111966)
* Mon Apr 22 2019 malbu@suse.com
- Update to Tomcat 9.0.19. See changelog at
  http://tomcat.apache.org/tomcat-9.0-doc/changelog.html#Tomcat_9.0.19_(markt)
  Notable packaging changes:
  - File /usr/share/java/tomcat/catalina-jmx-remote.jar was removed.
    The classes contained in this jar were merged into
    /usr/share/java/tomcat/catalina.jar.
- Fixed CVEs:
  - CVE-2019-0199 (bsc#1131055)
- Rebased patch:
  - tomcat-9.0-JDTCompiler-java.patch
  - tomcat-9.0-javadoc.patch
* Mon Apr 15 2019 Fridrich Strba <fstrba@suse.com>
- Build classpath directly with the geronimo jars instead of with
  symlinks to them
* Tue Feb 19 2019 malbu@suse.com
- Don't overwrite changes made to server.xml contexts when updating
  bundled webapps.
* Mon Feb 18 2019 malbu@suse.com
- Set javac target to 1.8 when building docs samples and serverxmltool
* Tue Feb  5 2019 malbu@suse.com
- Move webapps bundled with Tomcat to /usr/share/tomcat/tomcat-webapps
  (bsc#1092341). Affected packages:
  - tomcat-webapps
  - tomcat-admin-webapps
  - tomcat-docs-webapp
- Remove %%doc directive from tomcat-docs-webapps files section so that
  zypper installs files even if rpm.install.excludedocs is set to yes.
* Mon Feb  4 2019 malbu@suse.com
- Require Java 1.8 or later (bsc#1123407)
* Sat Jan 26 2019 Fridrich Strba <fstrba@suse.com>
- Clean up OSGi manifest injection
- Put embed maven metadata into embed subpackage
- Use the .mfiles* lists generated by %%%%add_maven_depmap macro
* Wed Jan 16 2019 malbu@suse.com
- Fix tomcat-tool-wrapper classpath error (bsc#1120745)
* Fri Jan 11 2019 malbu@suse.com
- Fix tomcat-digest classpath error (bsc#1120745)
* Sat Dec 29 2018 ecsos@opensuse.org
- Update to Tomcat 9.0.14. See changelog at
  http://tomcat.apache.org/tomcat-9.0-doc/changelog.html#Tomcat_9.0.14_(markt)
* Wed Dec  5 2018 Fridrich Strba <fstrba@suse.com>
- Add pom files for tomcat-jdbc and tomcat-dbcp
- Add org.eclipse.jetty.orbit* aliases to correspondant artifacts
* Fri Nov  9 2018 sean@suspend.net
- Update to Tomcat 9.0.13. See changelog at
  http://tomcat.apache.org/tomcat-9.0-doc/changelog.html#Tomcat_9.0.13_(markt)
* Thu Oct 18 2018 malbu@suse.com
- Update to Tomcat 9.0.12. See changelog at
  http://tomcat.apache.org/tomcat-9.0-doc/changelog.html#Tomcat_9.0.12_(markt)
- Fixed CVEs:
  - CVE-2018-11784 (bsc#1110850)
- Rebased patches:
  - tomcat-9.0-disable-osgi-build.patch
  - tomcat-9.0-javadoc.patch
  - tomcat-9.0-sle.catalina.policy.patch
  - tomcat-9.0-tomcat-users-webapp.patch
* Tue Sep 11 2018 ecsos@opensuse.org
- Declare following files to config(noreplace) to prevent override
  access rights:
  - host-manager/META-INF/context.xml
  - manager/META-INF/context.xml
* Sun Aug 26 2018 malbu@suse.com
- Empty tomcat-9.0.sysconfig to avoid overwriting of customer's
  configuration during update (bsc#1067720)
* Thu Aug 16 2018 malbu@suse.com
- Update to Tomcat 9.0.10. See changelog at
  http://tomcat.apache.org/tomcat-9.0-doc/changelog.html#Tomcat_9.0.10_(markt)
- Fixed CVEs:
  - CVE-2018-1336 (bsc#1102400)
  - CVE-2018-8014 (bsc#1093697)
  - CVE-2018-8034 (bsc#1102379)
  - CVE-2018-8037 (bsc#1102410)
- Rebased patch tomcat-9.0-JDTCompiler-java.patch
- Added patch tomcat-9.0-disable-osgi-build.patch to disable adding
  OSGi metadata to JAR files
* Fri Feb 16 2018 malbu@suse.de
- Update to Tomcat 9.0.5. See changelog at
  http://tomcat.apache.org/tomcat-9.0-doc/changelog.html#Tomcat_9.0.5_(markt)
* Wed Jan 17 2018 fstrba@suse.com
- Modified patch:
  * tomcat-9.0-javadoc.patch
    + Don't append to javadoc --add-modules since we are building
    with source=8
    + Avoid accessing Internet URLs from build environment
* Fri Dec  1 2017 malbu@suse.com
- Update to Tomcat 9.0.2:
  * Major update for tomcat8 from tomcat9
  * For full changelog please read upstream changes at:
    + http://tomcat.apache.org/tomcat-9.0-doc/changelog.html
  * Rename all tomcat-8.0-* files to tomcat-9.0-*
- Changed patches:
  * Deleted: tomcat-8.0-bootstrap-MANIFEST.MF.patch
  * Deleted: tomcat-8.0-sle.catalina.policy.patch
  * Deleted: tomcat-8.0-tomcat-users-webapp.patch
  * Deleted: tomcat-8.0.33-JDTCompiler-java.patch
  * Deleted: tomcat-8.0.44-javadoc.patch
  * Deleted: tomcat-8.0.9-property-build.windows.patch
  * Added: tomcat-9.0-JDTCompiler-java.patch
  * Added: tomcat-9.0-bootstrap-MANIFEST.MF.patch
  * Added: tomcat-9.0-javadoc.patch
  * Added: tomcat-9.0-sle.catalina.policy.patch
  * Added: tomcat-9.0-tomcat-users-webapp.patch
- Renamed subpackage tomcat-3_1-api to tomcat-4_0-api
  to reflect the new Servlet API version.
- Commented out JAVA_HOME in /etc/tomcat/tomcat.conf
- Added "tomcat-" prefix to lib symlinks under
  /usr/share/java to avoid file conflicts with servletapi5
  and geronimo-specs
- Fixed wrong %%ghost file paths for alternatives symlinks
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Mon Oct 23 2017 malbu@suse.com
- Build with JDK 8 to fix runtime errors when running with JDK 7
  and 8
- Fix tomcat-digest classpath error (bsc#977410)
- Fix packaged /etc/alternatives symlinks for api libs that caused
  rpm -V to report link mismatch (bsc#1019016)
* Mon Oct 23 2017 ecsos@opensuse.org
- update to 8.0.47
  http://tomcat.apache.org/tomcat-8.0-doc/changelog.html
  * Fixed CVE:
  - CVE-2017-12617
- rebase tomcat-8.0-sle.catalina.policy.patch
* Tue Sep 19 2017 fstrba@suse.com
- Added patch:
  * tomcat-8.0.44-javadoc.patch
  - generate documentation with the same source level as class
    files
  - fixes build with jdk9
* Fri Jun  9 2017 ecsos@opensuse.org
- Version update to 8.0.44:
  http://tomcat.apache.org/tomcat-8.0-doc/changelog.html
  * Fixed CVE:
  - CVE-2017-5664 (bsc#1042910)
* Fri May 19 2017 dziolkowski@suse.com
- New build dependency: javapackages-local
* Tue May  9 2017 malbu@suse.com
- Version update to 8.0.43:
  * Another bugfix release, for full details see:
    http://tomcat.apache.org/tomcat-8.0-doc/changelog.html
  * Fixed CVEs:
  - CVE-2017-5647 (bnc#1033448)
  - CVE-2017-5648 (bnc#1033447)
  - CVE-2016-8745
- Renamed and rebased patches:
  * tomcat-7.0-sle.catalina.policy.patch -> tomcat-8.0-sle.catalina.policy.patch
- Enable optional setenv.sh script. See section
  "(3.4) Using the "setenv" script (optional, recommended)" in
  http://tomcat.apache.org/tomcat-8.0-doc/RUNNING.txt
  (bnc#1002662)
- Fix file conflicts when upgrading from SLES 12 to SLES 12 SP1 (bnc#1023412).
  Added explicit obsoletes for tomcat-el-2_2-api, tomcat-jsp-2_2-api,
  tomcat-servlet-3_0-api
* Wed Dec 21 2016 astieger@suse.com
- update to 8.0.39: (boo#1003911)
  * Improve handling of I/O errors with async processing
  * Fail earlier on invalid HTTP request
- includes changes from  8.0.38:
  * Refactoring the non-container thread Async complete()/dispatch()
    handling to remove the possibility of deadlock
  * Improved UTF-8 handling for the RewriteValve
- includes changes from 8.0.37:
  * Treat paths used to obtain a request dispatcher as encoded
    (configurable)
  * Various jdbc-pool fixes
- drop tomcat-8.0.36-jar-scanner-loop.patch, upstream
* Thu Sep 29 2016 tchvatal@suse.com
- Switch to commons-dbcp2 fate#321029
* Fri Sep  2 2016 malbu@suse.com
- Backport fix for inifinite loop in the jar scanner for 8.0.36. (bnc#993862)
  Added: tomcat-8.0.36-jar-scanner-loop.patch
* Wed Jul  6 2016 malbu@suse.com
- Version update to 8.0.36:
  * Another bugfix release for the 8.0 series. Full details:
    http://tomcat.apache.org/tomcat-8.0-doc/changelog.html#Tomcat_8.0.36_(markt)
- CVE fixed by the version update:
  - CVE-2016-3092 (bnc#986359)
- Fixed a deployment error in the examples webapp by changing the context.xml format to the new one
  introduced by Tomcat 8. See http://tomcat.apache.org/migration-8.html#Web_application_resources
* Mon May  2 2016 dmacvicar@suse.de
- fix maven fragments paths to build in multiple distribution
  versions
* Thu Apr 21 2016 jcnengel@gmail.com
- Version update to 8.0.33:
  * Another bugfix release for 8.0 series, full details:
    http://tomcat.apache.org/tomcat-8.0-doc/changelog.html#Tomcat_8.0.33_(markt)
- Rebase tomcat-8.0-tomcat-users-webapp.patch
- Rebase tomcat-7.0.53-JDTCompiler-java.patch
  to tomcat-8.0.33-JDTCompiler-java.patch
* Thu Apr  7 2016 tchvatal@suse.com
- Fix fixme for the prereq preamble value
- It seems systemd prints error on adding the @ services to macros
  so do not do that
* Thu Mar 31 2016 dmacvicar@suse.de
- package was partly merged with the scripts used in the
  Fedora distribution
- support running multiple tomcat instances on the same server
  (fate#317783)
- add catalina-jmx-remote.jar (fate#318403)
- remove sysvinit support: systemd is required
* Mon Feb 29 2016 dmacvicar@suse.de
- update changes file for CVE information
- Fixed CVEs:
  - CVE-2015-5346 (bnc#967814) in 8.0.32
  - CVE-2015-5351 (bnc#967812) in 8.0.32
  - CVE-2016-0706 (bnc#967815) in 8.0.32
  - CVE-2016-0714 (bnc#967964) in 8.0.32
  - CVE-2016-0763 (bnc#967966) in 8.0.32
  - CVE-2015-5345 (bnc#967965) in 8.0.30
  - CVE-2015-5174 (bnc#967967) in 8.0.27
* Wed Feb 17 2016 tchvatal@suse.com
- Version update to 8.0.32:
  * Another bugfix release for 8.0 series, full details:
    http://tomcat.apache.org/tomcat-8.0-doc/changelog.html#Tomcat_8.0.32_(markt)
- Rebase patch:
  * tomcat-8.0.9-property-build.windows.patch
* Tue Nov 10 2015 dmacvicar@suse.de
- update to Tomcat 8.0.28
  * Multiple fixes, read upstream changelog at:
  https://tomcat.apache.org/tomcat-8.0-doc/changelog.html#Tomcat_8.0.28_(markt)
* Mon Jun  1 2015 tchvatal@suse.com
- Some whitespace cleanups
* Mon Jun  1 2015 tchvatal@suse.com
- Remove pointless conflicts on provide/obsolete symbols
* Mon Jun  1 2015 tchvatal@suse.com
- Version bump to 8.0.23 fate#318913:
  * Multiple testfixes all around, read upstream changelog at:
  http://tomcat.apache.org/tomcat-8.0-doc/changelog.html#Tomcat_8.0.23_(markt)
* Tue Mar 24 2015 tchvatal@suse.com
- Fix previous commit. Fix one rpmlint warning
* Wed Mar 18 2015 tchvatal@suse.com
- Drop gpg verification from spec, it is done by obs
* Wed Mar 18 2015 tchvatal@suse.com
- Fix build with new jpackage-tools
* Tue Feb 10 2015 wittemar@googlemail.com
- update to Tomcat 8.0.18:
  * Major update for tomcat8 from tomcat7
  * For full changelog please read upstream changes at:
    + http://tomcat.apache.org/tomcat-8.0-doc/changelog.html
  * Rename all tomcat-7.0-* files to tomcat-8.0-*
  * Update keyring file
- Update windows patch to apply again:
  * Deleted: tomcat-7.0.52-property-build.windows.patch
  * Added: tomcat-8.0.9-property-build.windows.patch
  * Added:tomcat-8.0-tomcat-users-webapp.patch
  * Deleted: tomcat-7.0-tomcat-users-webapp.patch
  * Added: tomcat-8.0-bootstrap-MANIFEST.MF.patch
  * Deleted: tomcat-7.0-bootstrap-MANIFEST.MF.patch
* Tue Feb  3 2015 bmaryniuk@suse.com
- Version 1.1.30 or higher is required for APR listener (bnc#914725)
* Wed Sep 17 2014 bmaryniuk@suse.com
- SLE12 has different path for the "rm" command than older versions.
  To avoid possible clashes, the entire coreutils must be provided.
  (bnc#894292)
* Tue Sep 16 2014 bmaryniuk@suse.com
- Fixed Security Manager policies, which makes unable properly
  run webapps by default. (bnc#891264)
  Added: tomcat-7.0-sle.catalina.policy.patch
* Tue Sep 16 2014 bmaryniuk@suse.com
- Missing security manager policy file prevents Tomcat to start
  with systemd. (bnc#890995)
* Mon Sep 15 2014 dmacvicar@suse.de
- Tomcat 7.0.55 requires ecj 4.4.0
* Mon Sep  8 2014 dmacvicar@suse.de
- include the tomcat websocket implementation (tomcat7-websocket)
* Mon Sep  8 2014 dmacvicar@suse.de
- Update to 7.0.55
  * Update to the Eclipse JDT Compiler 4.4
  * Better error handling when the error occurs after the response
    has been committed
  * Various improvements to the Mapper including fixing some
    concurrency bugs
  * See http://tomcat.apache.org/tomcat-7.0-doc/changelog.html
* Mon Sep  8 2014 dmacvicar@suse.de
- build tomcat-embed as a subpackage
* Wed Sep  3 2014 tchvatal@suse.com
- Drop two unused defines
* Wed Sep  3 2014 dmacvicar@suse.de
- touch the alternatives files to avoid build errors
  in older versions
* Tue Jul 29 2014 tchvatal@suse.com
- Do not define default defattr as it is pointless.
* Fri Jul 25 2014 tchvatal@suse.com
- One file here was not supposed to be ghost.
* Sat Jul 19 2014 tchvatal@suse.com
- Fix once more the alternatives.
* Fri Jul 11 2014 tchvatal@suse.com
- Add path to rm command.
* Fri Jul 11 2014 tchvatal@suse.com
- Silence loads of warnings by rpmlintrc
* Thu Jul 10 2014 tchvatal@suse.com
- Cleanup with spec-cleaner and format few things a bit.
* Thu Jul 10 2014 tchvatal@suse.com
- Remove few deps not really needed for sle11.
* Thu Jul 10 2014 tchvatal@suse.com
- Drop unused files obs.bl and local.lb
- Drop unused collections-tomcat-build.xml
* Sat May 24 2014 tchvatal@suse.com
- Version bump to 7.0.54:
  * bugfix update
  * See http://tomcat.apache.org/tomcat-7.0-doc/changelog.html
* Thu May 15 2014 darin@darins.net
- Update to 7.0.53
  * bugfix release
  * Update the Eclipse JDT compiler to enable full Java 8 support in JSPs.
  * See http://tomcat.apache.org/tomcat-7.0-doc/changelog.html
- Patch for Bug 56373
  * See https://issues.apache.org/bugzilla/show_bug.cgi?id=56373
  * tomcat-7.0.53-JDTCompiler-java.patch
- Rename tomcat-7.0.2-property-build.windows.patch to
  tomcat-7.0.52-property-build.windows.patch
* Thu May 15 2014 darin@darins.net
- remove saxon build requirement for sles
- disable bytecode check for sles
* Mon Apr 14 2014 darin@darins.net
- remove unknown option from fillup_only macro
- wrap systemd %%pre[un]/%%post[un] in conditional
- specify required ant version
* Tue Apr  8 2014 wittemar@googlemail.com
- Update to 7.0.52
  * bugfix release
  * Fix CVE-2014-0050, a DoS vulnerability related to multi-part processing
- Update to 7.0.50
  * bugfix release
* Thu Dec 12 2013 mvyskocil@suse.com
- Add missing commons-pool-tomcat5 symlink (bnc#847505c#13)
* Mon Nov  4 2013 mvyskocil@suse.com
- Update to 7.0.47
  * bugfix release
  * backport of JSR-356 Java WebSocket 1.0
  * package tomcat now requires java7 at lease
- Updated tomcat.keyring to reflect the fact new release is signed by
  Violeta Georgieva / D63011C7
  see http://osdir.com/ml/dev-tomcat.apache.org/2013-10/msg00849.html
- Add tomcat-dbcp.jar (bnc#847505) back into tomcat lib dir
- Install tomcat-coyote.jar as well
- Remove pointless scriplets
* Mon Sep  9 2013 tchvatal@suse.com
- Move from jpackage-utils to javapackage-tools
* Thu Sep  5 2013 mvyskocil@suse.com
- drop a dependency on unecessary -tomcat5 packages
- use commons-dbcp.jar for build
- add missing commons-pool.jar to libdir
* Fri Aug  9 2013 mvyskocil@suse.com
- add _constraints to not schedule build on some build machines
  workaround for bnc#832762
* Tue Aug  6 2013 robert.munteanu@gmail.com
- Add missing 'su root tomcat' line to logrotate. See also
  https://bugzilla.redhat.com/show_bug.cgi?id=790334
* Fri Jul 26 2013 mvyskocil@suse.com
- call chown --no-dereference in init script
  (bnc#822177#c7/prevents CVE-2013-1976)
* Tue Jul 23 2013 mvyskocil@suse.com
- update to 7.0.42 (bugfix release)
  see http://tomcat.apache.org/tomcat-7.0-doc/changelog.html
- fix file list to be compatible for new rpm
* Thu Apr 18 2013 mvyskocil@suse.com
- update to 7.0.39 (bugfix release)
- install only systemd unit files on openSUSE 12.1+
  * and call proper code when init script still exists
- add a proper scripplets for -jsvc subpackage
- don't use catalina.out, systemd redirects stderr/stdout to syslog
- don't use and recommends logrotate
- package /etc/ant.d properly, mark only catalina-ant as a config file
* Sat Feb 16 2013 m407@mail.ru
- Fix tomcat init scripts generating malformed classpath
  (http://youtrack.jetbrains.com/issue/JT-18545)
  bnc#804992
* Mon Jan 21 2013 mvyskocil@suse.com
- update to 7.0.35 (bugfix release)
  require ecj >= 4.2.1, like upstream do
- make gpg-offline work distros after 12.2
* Thu Dec 27 2012 archie@dellroad.org
- Ensure tomcat stdout/stderr output ends up in catalina.out
* Thu Dec 20 2012 archie@dellroad.org
- Recommend libtcnative-1-0 >= 1.1.24
- /etc/init.d/tomcate init script fixes:
  * Include /usr/bin and /usr/sbin in the PATH
  * Fix logic for cleaning the work directories
  * Fix typo (log_success_msg lsb function name)
  * Fix typo (reload message)
- Require log4j
* Tue Dec 18 2012 mvyskocil@suse.com
- Require gpg-offline on 12.2+
* Thu Nov 29 2012 sbrabec@suse.cz
- Verify GPG signature.
* Mon Nov 26 2012 mvyskocil@suse.com
- update to 7.0.33 (bugfix release)
* Tue Sep 11 2012 mvyskocil@suse.cz
- update to 7.0.30 (bugfix release)
  * SSI and CGI disabled by default
- fix bnc#779538: change the working dir to $CATALINA_BASE
- document the CATALINA_BASE and CATALINA_HOME in tomcat.conf better
- fix rpmlintrc file
* Thu Jul 19 2012 mvyskocil@suse.cz
- fix bnc#771802 - systemd support is broken
  * change type froking to simple as it does not make a sense run java in a
    background to emulate that
  * remove the need of nested wrappers, so /usr/sbin/tomcat-sysd now relies on
    systemd features like User/EnvironmentFile
  * workaround the 143 exit code in Stop phase - return 0 in this case
  * merge the jsvc into tomcat-sysd code, the -jsvc-sysd is a symlink
  * properly use jsvc with pid file to start and stop
* Wed Jun 13 2012 mvyskocil@suse.cz
- update to 7.0.26 (bugfix release)
- rename package to tomcat in order to emphasise a fact, there is only one
  major release of tomcat maintained in distribution
- add manifest files and systemd support (thanks Fedora)
- create tomcat-jsvc package
* Thu Feb 23 2012 mvyskocil@suse.cz
- update to 7.0.26 (bugfix release)
- fix bnc#747771 - don't use /var/lock/subsys
  sync tomcat7 init with tomcat6
* Sun Feb 19 2012 wittemar@googlemail.com
- update to 7.0.25 (bugfix release)
* Tue Nov  1 2011 mvyskocil@suse.cz
- update to 7.0.22 (bugfix release)
- wrote changes and prepare for inclusion to openSUSE distribution
- fix bnc#726307
  /etc/tomcat7 is writtable for tomcat group
* Mon Sep 19 2011 wittemar@googlemail.com
- update to version 7.0.21
* Thu Jul 21 2011 mvyskocil@suse.cz
- update to version 7.0.16 (bugfix update)
* Wed Mar 30 2011 jrenner@suse.de
- add rpmlintrc, digest, init and wrapper scripts and config file
  - build require geronimo apis and wsdl4j
  - disable webservices in javadoc target
* Tue Jan 18 2011 mvyskocil@suse.cz
- initial packaging of tomcat7 7.0.6
